var searchData=
[
  ['p',['p',['../structnnpi.html#a405ddb3cd2a34a1a7096e00459c094b8',1,'nnpi::p()'],['../structplplot_1_1__N10.html#af2559d3378c813b49843600fb0400e78',1,'plplot::_N10::p()'],['../structPLControlPt.html#abeb78829776244dc4586df699a7965a7',1,'PLControlPt::p()']]],
  ['pack',['pack',['../structSwigPyPacked.html#af5122bcb9e73bf2dec4ce5f58f004e1b',1,'SwigPyPacked']]],
  ['page',['page',['../structPLmDev.html#ae972fa1f1e2461c22e5aeda23e2fc8ed',1,'PLmDev::page()'],['../structPLStream.html#a448034861d845f7a1357844d11e7fbe9',1,'PLStream::page()']]],
  ['page_5f2005_5fheader',['page_2005_header',['../plmetafile_8c.html#a3ab65bd0b91c2ed318f37111e15f5da1',1,'plmetafile.c']]],
  ['page_5fstatus',['page_status',['../structPLStream.html#a5000900b730320fb06805aa716802a64',1,'PLStream']]],
  ['pages',['pages',['../structPLmIndex.html#a8ba736ea874c6c06af04405d135bd98c',1,'PLmIndex']]],
  ['pangomarkupstring',['pangoMarkupString',['../structPLCairo.html#a8a705cc93ae920236420ae9da1d16e35',1,'PLCairo']]],
  ['parent',['parent',['../structtriangle.html#a3fb1ed5646ccc6e7ce83cc94b0b96dce',1,'triangle::parent()'],['../structsquare.html#a43a948eec95865d74b86c86454205d8b',1,'square::parent()']]],
  ['pass_5fthru',['pass_thru',['../structTkDev.html#ad74b6e42430b76119f75eb3a1b8cf63b',1,'TkDev']]],
  ['patt',['patt',['../structDIR.html#ace108a5f819d5ff56b7946fcb450a823',1,'DIR::patt()'],['../structPLStream.html#a97e193646567fa5d487c29e16ee5c398',1,'PLStream::patt()']]],
  ['pattern',['pattern',['../plsdef_8c.html#a5189105c1d92cea43bbe3505864ed37c',1,'plsdef.c']]],
  ['pdf_5ftype',['pdf_type',['../struct__plm__format.html#a94f3a8c9820be9fb51484c0525e0f270',1,'_plm_format']]],
  ['pdfs',['pdfs',['../structPLRDev.html#ac683de1a4376e9a29c55177a1b21bfd5',1,'PLRDev::pdfs()'],['../structPLStream.html#adbc1c6f49171693ded97033012fc5377',1,'PLStream::pdfs()']]],
  ['pen_5fcol_5fmax',['pen_col_max',['../plshade_8c.html#a21497d4ad88ba36522144b445236e224',1,'plshade.c']]],
  ['pen_5fcol_5fmin',['pen_col_min',['../plshade_8c.html#ace5ab1fe7b90fde892fc90c5ff150009',1,'plshade.c']]],
  ['pen_5fwd_5fmax',['pen_wd_max',['../plshade_8c.html#a1790b48b7f5b1d4be93fadcd1c0cea06',1,'plshade.c']]],
  ['pen_5fwd_5fmin',['pen_wd_min',['../plshade_8c.html#ac159bf0fc1ce49e8ae7a0208145fe097',1,'plshade.c']]],
  ['pendn',['pendn',['../structPLStream.html#a3c31ecd3a5fdf70ffd2cef5ce1e9ddf8',1,'PLStream']]],
  ['pfont',['pfont',['../structFCI__to__FontName__Table.html#a6754a99ae7167e94b5340443d5b6f996',1,'FCI_to_FontName_Table']]],
  ['phyxlen',['phyxlen',['../structPLStream.html#ab486e5550932eed05f4d67642acfb322',1,'PLStream']]],
  ['phyxma',['phyxma',['../structPLStream.html#af23066971554d9721b1c1d1a86d8e3b2',1,'PLStream']]],
  ['phyxmi',['phyxmi',['../structPLStream.html#ab74c69a6d7c33eac59b640e18607c2ba',1,'PLStream']]],
  ['phyylen',['phyylen',['../structPLStream.html#a085b419f0ed385e70d076be15d6181f3',1,'PLStream']]],
  ['phyyma',['phyyma',['../structPLStream.html#aa616b132f7f3a8b826a147be4161787a',1,'PLStream']]],
  ['phyymi',['phyymi',['../structPLStream.html#a9d667e6d3c8c695daa1c62ffe2b39d98',1,'PLStream']]],
  ['picnum',['picnum',['../structcdImageStruct.html#a811fcf55cd8f69ca43968a8b5701dab1',1,'cdImageStruct']]],
  ['pixeldevice',['pixelDevice',['../structdev__entry.html#a81ef42456e372a53ff781bfa6054fa19',1,'dev_entry']]],
  ['pixmap',['pixmap',['../structTkwDev.html#a6b698f2ae4848f1f2e6965f248fbba17',1,'TkwDev::pixmap()'],['../structXwDev.html#a3939428f0e71cdfaa5f72cc508294fb0',1,'XwDev::pixmap()']]],
  ['pl3mode',['pl3mode',['../plot3d_8c.html#a5d3834ebbb0d8d4666e15764968670b6',1,'plot3d.c']]],
  ['pl3upv',['pl3upv',['../plot3d_8c.html#a4fccd357be6368a4f1153f2f3e5f4f52',1,'plot3d.c']]],
  ['pl_5fbin_5fcentred',['PL_BIN_CENTRED',['../classplplot.html#a8b4bb482aa4a3b5d387abd08ee17447d',1,'plplot::PL_BIN_CENTRED()'],['../namespaceplplotc.html#a344bc3e3683d146d84938050a523b428',1,'plplotc.PL_BIN_CENTRED()'],['../namespaceplplotc__fixed.html#a3517f1d14b80a7ecaf6bbea0f2a24f73',1,'plplotc_fixed.PL_BIN_CENTRED()']]],
  ['pl_5fbin_5fdefault',['PL_BIN_DEFAULT',['../classplplot.html#aee6daf582b74c0c933b4c41785d6b758',1,'plplot::PL_BIN_DEFAULT()'],['../namespaceplplotc.html#a42cfddc5110553983498c4ca88e4c37b',1,'plplotc.PL_BIN_DEFAULT()'],['../namespaceplplotc__fixed.html#ac99e2c501d9612ad3f55b346113e009d',1,'plplotc_fixed.PL_BIN_DEFAULT()']]],
  ['pl_5fbin_5fnoempty',['PL_BIN_NOEMPTY',['../classplplot.html#aa8d1c08833503083724c3a0a43439338',1,'plplot::PL_BIN_NOEMPTY()'],['../namespaceplplotc.html#ada2b3d0d0d635a3a204008e7e1601bb9',1,'plplotc.PL_BIN_NOEMPTY()'],['../namespaceplplotc__fixed.html#a9cab171c91438403fe75b8722bb29c7c',1,'plplotc_fixed.PL_BIN_NOEMPTY()']]],
  ['pl_5fbin_5fnoexpand',['PL_BIN_NOEXPAND',['../classplplot.html#a861aa362a8d7f9831098df18043b7174',1,'plplot::PL_BIN_NOEXPAND()'],['../namespaceplplotc.html#a45b532276b964995dd6fc5409c84bad9',1,'plplotc.PL_BIN_NOEXPAND()'],['../namespaceplplotc__fixed.html#ab0fa74cb960def06a8bc34517c2663a3',1,'plplotc_fixed.PL_BIN_NOEXPAND()']]],
  ['pl_5fbop',['pl_bop',['../structPLDispatchTable.html#acb9e7a07206b30c76ad6b14324f7e179',1,'PLDispatchTable']]],
  ['pl_5fcolorbar_5fbackground',['PL_COLORBAR_BACKGROUND',['../classplplot.html#a21c06c6b1e046ab4475a0be61786056a',1,'plplot::PL_COLORBAR_BACKGROUND()'],['../namespaceplplotc.html#af95a7d5b0978b75e6d22742693ef378d',1,'plplotc.PL_COLORBAR_BACKGROUND()'],['../namespaceplplotc__fixed.html#ab0e903cae4320897f2dff895f1bf8e1c',1,'plplotc_fixed.PL_COLORBAR_BACKGROUND()']]],
  ['pl_5fcolorbar_5fbounding_5fbox',['PL_COLORBAR_BOUNDING_BOX',['../classplplot.html#a9e3ede3e77dd286ead007636997e9fdf',1,'plplot::PL_COLORBAR_BOUNDING_BOX()'],['../namespaceplplotc.html#a911b70c3cb2e34e5177f3ef32a995462',1,'plplotc.PL_COLORBAR_BOUNDING_BOX()'],['../namespaceplplotc__fixed.html#a5ff77f495d2609941495780f0ac6ae54',1,'plplotc_fixed.PL_COLORBAR_BOUNDING_BOX()']]],
  ['pl_5fcolorbar_5fcap_5fhigh',['PL_COLORBAR_CAP_HIGH',['../classplplot.html#a45c37e1750252906687fa48e8b1b952e',1,'plplot::PL_COLORBAR_CAP_HIGH()'],['../namespaceplplotc.html#a2cab6556f35bc5a4898c23a29b183ae6',1,'plplotc.PL_COLORBAR_CAP_HIGH()'],['../namespaceplplotc__fixed.html#af2b25ae6ce5d3fa3c97f9a4370cc6700',1,'plplotc_fixed.PL_COLORBAR_CAP_HIGH()']]],
  ['pl_5fcolorbar_5fcap_5flow',['PL_COLORBAR_CAP_LOW',['../classplplot.html#af8a31f853ad692afcefda3b1403d48a3',1,'plplot::PL_COLORBAR_CAP_LOW()'],['../namespaceplplotc.html#a79edd218d6c47e279ed095bcc59c8f47',1,'plplotc.PL_COLORBAR_CAP_LOW()'],['../namespaceplplotc__fixed.html#ae248d522d24d1caebd49c6fd2d1df163',1,'plplotc_fixed.PL_COLORBAR_CAP_LOW()']]],
  ['pl_5fcolorbar_5fcap_5fnone',['PL_COLORBAR_CAP_NONE',['../classplplot.html#aec6961d048e4e6c44600167ba2eafe6e',1,'plplot::PL_COLORBAR_CAP_NONE()'],['../namespaceplplotc.html#ac930e9b816fcb74ea9c0767f32f3b05f',1,'plplotc.PL_COLORBAR_CAP_NONE()'],['../namespaceplplotc__fixed.html#a48b6b9e059818b0f8d165452be63dc09',1,'plplotc_fixed.PL_COLORBAR_CAP_NONE()']]],
  ['pl_5fcolorbar_5fgradient',['PL_COLORBAR_GRADIENT',['../classplplot.html#a3fbb9171d73f5670d2ebf52797775966',1,'plplot::PL_COLORBAR_GRADIENT()'],['../namespaceplplotc.html#acf97a545a8de2e5e86353b2dc8ba7ac1',1,'plplotc.PL_COLORBAR_GRADIENT()'],['../namespaceplplotc__fixed.html#a7e66639607fd0fe5b7043d5cc75c53c9',1,'plplotc_fixed.PL_COLORBAR_GRADIENT()']]],
  ['pl_5fcolorbar_5fimage',['PL_COLORBAR_IMAGE',['../classplplot.html#a54d83e729244593e941e983a178dcbed',1,'plplot::PL_COLORBAR_IMAGE()'],['../namespaceplplotc.html#a3f30322ca60a874f4fa5dde9eee730ea',1,'plplotc.PL_COLORBAR_IMAGE()'],['../namespaceplplotc__fixed.html#a36a2034b5ad205f8853a484ab10b5870',1,'plplotc_fixed.PL_COLORBAR_IMAGE()']]],
  ['pl_5fcolorbar_5flabel_5fbottom',['PL_COLORBAR_LABEL_BOTTOM',['../classplplot.html#afb7c78bd45e9cc20292b47aeba5f3cf6',1,'plplot::PL_COLORBAR_LABEL_BOTTOM()'],['../namespaceplplotc.html#ad9e518731ed5c7d83b1f23f54ff65e35',1,'plplotc.PL_COLORBAR_LABEL_BOTTOM()'],['../namespaceplplotc__fixed.html#a7b324c22c5f44eb09651d48b557b016d',1,'plplotc_fixed.PL_COLORBAR_LABEL_BOTTOM()']]],
  ['pl_5fcolorbar_5flabel_5fleft',['PL_COLORBAR_LABEL_LEFT',['../classplplot.html#ab931accd246a77a15f52bdcc128312b1',1,'plplot::PL_COLORBAR_LABEL_LEFT()'],['../namespaceplplotc.html#a3e4cf1bda8ba1c0505c9562b6c82750c',1,'plplotc.PL_COLORBAR_LABEL_LEFT()'],['../namespaceplplotc__fixed.html#a825e3b49926a9769ecc97a871c75b9ba',1,'plplotc_fixed.PL_COLORBAR_LABEL_LEFT()']]],
  ['pl_5fcolorbar_5flabel_5fright',['PL_COLORBAR_LABEL_RIGHT',['../classplplot.html#a3b408dc01e7d4e6d27e75f45aebb6910',1,'plplot::PL_COLORBAR_LABEL_RIGHT()'],['../namespaceplplotc.html#adc86862732c28d9f913aaccfdf3ada85',1,'plplotc.PL_COLORBAR_LABEL_RIGHT()'],['../namespaceplplotc__fixed.html#aea1aa0a6aaf3c47642b4e1ad1859feab',1,'plplotc_fixed.PL_COLORBAR_LABEL_RIGHT()']]],
  ['pl_5fcolorbar_5flabel_5ftop',['PL_COLORBAR_LABEL_TOP',['../classplplot.html#a043ad3aaaf5c6e4e8d4098a839c7a860',1,'plplot::PL_COLORBAR_LABEL_TOP()'],['../namespaceplplotc.html#a34f25c7749f9f2e7e4b57751f48a7a04',1,'plplotc.PL_COLORBAR_LABEL_TOP()'],['../namespaceplplotc__fixed.html#a2e33c774ad569b10d40a12bb0c9b768f',1,'plplotc_fixed.PL_COLORBAR_LABEL_TOP()']]],
  ['pl_5fcolorbar_5forient_5fbottom',['PL_COLORBAR_ORIENT_BOTTOM',['../classplplot.html#a45f22534aeca33d204ab1997e301d63b',1,'plplot::PL_COLORBAR_ORIENT_BOTTOM()'],['../namespaceplplotc.html#ae9209f36a0d585af6359b592de312c17',1,'plplotc.PL_COLORBAR_ORIENT_BOTTOM()'],['../namespaceplplotc__fixed.html#a151f79793661a886c93972d3807fd129',1,'plplotc_fixed.PL_COLORBAR_ORIENT_BOTTOM()']]],
  ['pl_5fcolorbar_5forient_5fleft',['PL_COLORBAR_ORIENT_LEFT',['../classplplot.html#a05c866ccb90c8f5e7f9fcba47ca06f97',1,'plplot::PL_COLORBAR_ORIENT_LEFT()'],['../namespaceplplotc.html#ab71b2b1310d91961d4474debc45f6795',1,'plplotc.PL_COLORBAR_ORIENT_LEFT()'],['../namespaceplplotc__fixed.html#ad0ee8a391149ce25705fe43c3290f582',1,'plplotc_fixed.PL_COLORBAR_ORIENT_LEFT()']]],
  ['pl_5fcolorbar_5forient_5fright',['PL_COLORBAR_ORIENT_RIGHT',['../classplplot.html#ab95f67a66d9c54530c49db3dc37409db',1,'plplot::PL_COLORBAR_ORIENT_RIGHT()'],['../namespaceplplotc.html#af433eeb18a32c898a75b2395d7469a56',1,'plplotc.PL_COLORBAR_ORIENT_RIGHT()'],['../namespaceplplotc__fixed.html#a59266a1b0898942313629e6321218796',1,'plplotc_fixed.PL_COLORBAR_ORIENT_RIGHT()']]],
  ['pl_5fcolorbar_5forient_5ftop',['PL_COLORBAR_ORIENT_TOP',['../classplplot.html#ada262759b3f6373dcbb2c0a268f26428',1,'plplot::PL_COLORBAR_ORIENT_TOP()'],['../namespaceplplotc.html#a52066881c06bed4cbeb01c5da3d74ccc',1,'plplotc.PL_COLORBAR_ORIENT_TOP()'],['../namespaceplplotc__fixed.html#a6fc5e03f74b32ecb7d8486bfc59d0474',1,'plplotc_fixed.PL_COLORBAR_ORIENT_TOP()']]],
  ['pl_5fcolorbar_5fshade',['PL_COLORBAR_SHADE',['../classplplot.html#a8913e33754cfef14eff15beb1bf46a5c',1,'plplot::PL_COLORBAR_SHADE()'],['../namespaceplplotc.html#a4ff5e3c86ff6f9d3e2e223c490fe8327',1,'plplotc.PL_COLORBAR_SHADE()'],['../namespaceplplotc__fixed.html#acad9ed45b778689543503d72bbd2e8bf',1,'plplotc_fixed.PL_COLORBAR_SHADE()']]],
  ['pl_5fcolorbar_5fshade_5flabel',['PL_COLORBAR_SHADE_LABEL',['../classplplot.html#ae9c45984e846d89e6311b679ebe5defe',1,'plplot::PL_COLORBAR_SHADE_LABEL()'],['../namespaceplplotc.html#ad5adcf8af18fbe8ade0593944543b260',1,'plplotc.PL_COLORBAR_SHADE_LABEL()'],['../namespaceplplotc__fixed.html#a8c9a62475f5f874a2638806d6af74c9f',1,'plplotc_fixed.PL_COLORBAR_SHADE_LABEL()']]],
  ['pl_5fdevname',['pl_DevName',['../structPLDispatchTable.html#a4f685b43a8469106700ce774db587743',1,'PLDispatchTable']]],
  ['pl_5fdrawmode_5fdefault',['PL_DRAWMODE_DEFAULT',['../namespaceplplotc.html#a4d91914c408b6a2404caad751109bdfa',1,'plplotc.PL_DRAWMODE_DEFAULT()'],['../namespaceplplotc__fixed.html#aba7ac399df96fd1cf2e9f050d4775a39',1,'plplotc_fixed.PL_DRAWMODE_DEFAULT()']]],
  ['pl_5fdrawmode_5freplace',['PL_DRAWMODE_REPLACE',['../namespaceplplotc.html#a63a3b10a62df8f5eff9deb07d38bbef6',1,'plplotc.PL_DRAWMODE_REPLACE()'],['../namespaceplplotc__fixed.html#afe811426ef13242a769f4032ba90b9f8',1,'plplotc_fixed.PL_DRAWMODE_REPLACE()']]],
  ['pl_5fdrawmode_5funknown',['PL_DRAWMODE_UNKNOWN',['../namespaceplplotc.html#a28125d34c086e0128f19a6c8a7ed0dac',1,'plplotc.PL_DRAWMODE_UNKNOWN()'],['../namespaceplplotc__fixed.html#a31306905677dd8785f44cd76c8e022d5',1,'plplotc_fixed.PL_DRAWMODE_UNKNOWN()']]],
  ['pl_5fdrawmode_5fxor',['PL_DRAWMODE_XOR',['../namespaceplplotc.html#ac4cd01bfca501d2b0fab88269b97cd4d',1,'plplotc.PL_DRAWMODE_XOR()'],['../namespaceplplotc__fixed.html#a9f8cf9ba99fa551633dd122213841d08',1,'plplotc_fixed.PL_DRAWMODE_XOR()']]],
  ['pl_5fend_5fof_5fstring',['pl_end_of_string',['../classplplot.html#ac0b4623331c1704fba8ab480d3ed938c',1,'plplot']]],
  ['pl_5feop',['pl_eop',['../structPLDispatchTable.html#a4b235deb2683b3789b421c115d9ddb8f',1,'PLDispatchTable']]],
  ['pl_5ferrcode',['pl_errcode',['../tclAPI_8c.html#aa4330b21fe130af134956c1e90251854',1,'tclAPI.c']]],
  ['pl_5fesc',['pl_esc',['../structPLDispatchTable.html#a6f80e444bd2f30f633af54505e7b3de0',1,'PLDispatchTable']]],
  ['pl_5ffci_5fbold',['PL_FCI_BOLD',['../classplplot.html#ad5c19171b3782b2b1c76d3b6dbe4e41c',1,'plplot::PL_FCI_BOLD()'],['../namespaceplplotc.html#a2c7bb357576ac33c8276882983ecffac',1,'plplotc.PL_FCI_BOLD()'],['../namespaceplplotc__fixed.html#ad72ae3b2d8a287ad229c67c425941cc3',1,'plplotc_fixed.PL_FCI_BOLD()']]],
  ['pl_5ffci_5ffamily',['PL_FCI_FAMILY',['../classplplot.html#af00dc4a620e90ffd9481790fc7396ce7',1,'plplot::PL_FCI_FAMILY()'],['../namespaceplplotc.html#aaf207b29fc82b13ce1ce2f128ca5f37b',1,'plplotc.PL_FCI_FAMILY()'],['../namespaceplplotc__fixed.html#a3b97777adb92c9eb0c9ea732e9a07b53',1,'plplotc_fixed.PL_FCI_FAMILY()']]],
  ['pl_5ffci_5fhexdigit_5fmask',['PL_FCI_HEXDIGIT_MASK',['../classplplot.html#a6e2bbc3ec109f773d0b9d6ff6c6c4110',1,'plplot::PL_FCI_HEXDIGIT_MASK()'],['../namespaceplplotc.html#a572183dfc5e2aacd72c5d46ada49772f',1,'plplotc.PL_FCI_HEXDIGIT_MASK()'],['../namespaceplplotc__fixed.html#a1b0a49b8566da86966d12fd438139f5d',1,'plplotc_fixed.PL_FCI_HEXDIGIT_MASK()']]],
  ['pl_5ffci_5fhexpower_5fimpossible',['PL_FCI_HEXPOWER_IMPOSSIBLE',['../classplplot.html#a0830e4784c9210bdc7d1a248c6a92616',1,'plplot::PL_FCI_HEXPOWER_IMPOSSIBLE()'],['../namespaceplplotc.html#a71e15c798240dd024f8ae5389501e87f',1,'plplotc.PL_FCI_HEXPOWER_IMPOSSIBLE()'],['../namespaceplplotc__fixed.html#a903d7de26f42d9ad16a3328316781662',1,'plplotc_fixed.PL_FCI_HEXPOWER_IMPOSSIBLE()']]],
  ['pl_5ffci_5fhexpower_5fmask',['PL_FCI_HEXPOWER_MASK',['../classplplot.html#a25300695cbc578f880a157945cc438b3',1,'plplot::PL_FCI_HEXPOWER_MASK()'],['../namespaceplplotc.html#aeba6a59a54184036d545cfaee0835afc',1,'plplotc.PL_FCI_HEXPOWER_MASK()'],['../namespaceplplotc__fixed.html#a3c4bad5545ab4b39bb9b8c6410e87b3d',1,'plplotc_fixed.PL_FCI_HEXPOWER_MASK()']]],
  ['pl_5ffci_5fimpossible',['PL_FCI_IMPOSSIBLE',['../classplplot.html#ae67da199d784c8752fdb8ddb7d371778',1,'plplot::PL_FCI_IMPOSSIBLE()'],['../namespaceplplotc.html#a59db6556c1037fa49ce96a07e48459d7',1,'plplotc.PL_FCI_IMPOSSIBLE()'],['../namespaceplplotc__fixed.html#a8074838b2c3a25bce8f6f478d79bd21a',1,'plplotc_fixed.PL_FCI_IMPOSSIBLE()']]],
  ['pl_5ffci_5fitalic',['PL_FCI_ITALIC',['../classplplot.html#acba7b79270e714987d94961e5053e36f',1,'plplot::PL_FCI_ITALIC()'],['../namespaceplplotc.html#a9f951c9bf12df563e8325e76ca9aaca0',1,'plplotc.PL_FCI_ITALIC()'],['../namespaceplplotc__fixed.html#a71852cbf28cf2c9b9b5e6ee91e686fa2',1,'plplotc_fixed.PL_FCI_ITALIC()']]],
  ['pl_5ffci_5fmark',['PL_FCI_MARK',['../classplplot.html#ad397ee04fd837f53bbd23168bc8938d9',1,'plplot::PL_FCI_MARK()'],['../namespaceplplotc.html#a6e7400cf778bda55234053f0a5bb833e',1,'plplotc.PL_FCI_MARK()'],['../namespaceplplotc__fixed.html#ae9d69421ba923b405806ac32c3ca8638',1,'plplotc_fixed.PL_FCI_MARK()']]],
  ['pl_5ffci_5fmedium',['PL_FCI_MEDIUM',['../classplplot.html#a880960d5564abca4dc5937ea0d8e3521',1,'plplot::PL_FCI_MEDIUM()'],['../namespaceplplotc.html#ac05bf1cddf518c5c5afb50f415915b90',1,'plplotc.PL_FCI_MEDIUM()'],['../namespaceplplotc__fixed.html#ac7548a45979109e6df038c95d317426a',1,'plplotc_fixed.PL_FCI_MEDIUM()']]],
  ['pl_5ffci_5fmono',['PL_FCI_MONO',['../classplplot.html#a16c198fd39b21e38ef459a11089b5740',1,'plplot::PL_FCI_MONO()'],['../namespaceplplotc.html#a63b05e5c0adf5f35662989ae1fae3f20',1,'plplotc.PL_FCI_MONO()'],['../namespaceplplotc__fixed.html#a7b57f02bf5179d13582f4f6b43622053',1,'plplotc_fixed.PL_FCI_MONO()']]],
  ['pl_5ffci_5foblique',['PL_FCI_OBLIQUE',['../classplplot.html#acf041a00a5aff414d8ef0338c79d1fde',1,'plplot::PL_FCI_OBLIQUE()'],['../namespaceplplotc.html#a0421edff31f5a68120efcf9c738c06b6',1,'plplotc.PL_FCI_OBLIQUE()'],['../namespaceplplotc__fixed.html#a71c03b3b5db18eeba8e71d407b4817b3',1,'plplotc_fixed.PL_FCI_OBLIQUE()']]],
  ['pl_5ffci_5fsans',['PL_FCI_SANS',['../classplplot.html#a16f0c9eaafc7a35c7d61e8f24ab095df',1,'plplot::PL_FCI_SANS()'],['../namespaceplplotc.html#a964ab0d5d6bb4c2a7a5b62bf56a13ad8',1,'plplotc.PL_FCI_SANS()'],['../namespaceplplotc__fixed.html#a14b71ec71ebb8601c7db2b7f46c4a220',1,'plplotc_fixed.PL_FCI_SANS()']]],
  ['pl_5ffci_5fscript',['PL_FCI_SCRIPT',['../classplplot.html#a4d553fa02b87433db091aa46dc601a5f',1,'plplot::PL_FCI_SCRIPT()'],['../namespaceplplotc.html#a16597c0a15eecef215370eed9d425f57',1,'plplotc.PL_FCI_SCRIPT()'],['../namespaceplplotc__fixed.html#ade9b493440c249ff0a44ef7a2147eff3',1,'plplotc_fixed.PL_FCI_SCRIPT()']]],
  ['pl_5ffci_5fserif',['PL_FCI_SERIF',['../classplplot.html#a6c3a63d8ab70e8c50d27e226c47dc802',1,'plplot::PL_FCI_SERIF()'],['../namespaceplplotc.html#ad964edc69413999f4cc508a3ed91bc38',1,'plplotc.PL_FCI_SERIF()'],['../namespaceplplotc__fixed.html#a1f25db12456b36d3c7c43022243b7e2f',1,'plplotc_fixed.PL_FCI_SERIF()']]],
  ['pl_5ffci_5fstyle',['PL_FCI_STYLE',['../classplplot.html#a210ca726e6dcdc4f56f1e3f5d9275711',1,'plplot::PL_FCI_STYLE()'],['../namespaceplplotc.html#a48d8e4607986d922bffd7f2440540bab',1,'plplotc.PL_FCI_STYLE()'],['../namespaceplplotc__fixed.html#acc9859099fba6a228dec00ebc12ef424',1,'plplotc_fixed.PL_FCI_STYLE()']]],
  ['pl_5ffci_5fsymbol',['PL_FCI_SYMBOL',['../classplplot.html#a5ae9d36b98641eaad957204227fd44cb',1,'plplot::PL_FCI_SYMBOL()'],['../namespaceplplotc.html#a7deb908680041aa6345b04e72e815092',1,'plplotc.PL_FCI_SYMBOL()'],['../namespaceplplotc__fixed.html#a5f28224978f7c6b755e887bdecdb7cf1',1,'plplotc_fixed.PL_FCI_SYMBOL()']]],
  ['pl_5ffci_5fupright',['PL_FCI_UPRIGHT',['../classplplot.html#a5232bd6cf21866b29048554dcdc40335',1,'plplot::PL_FCI_UPRIGHT()'],['../namespaceplplotc.html#a91b81d08c1ddc31132b0159b625e1127',1,'plplotc.PL_FCI_UPRIGHT()'],['../namespaceplplotc__fixed.html#a984c189fcf67a904ebb93890f57a7351',1,'plplotc_fixed.PL_FCI_UPRIGHT()']]],
  ['pl_5ffci_5fweight',['PL_FCI_WEIGHT',['../classplplot.html#afe1b47ac660b3c4b68ce68875297e521',1,'plplot::PL_FCI_WEIGHT()'],['../namespaceplplotc.html#a3a3f9833554fe851af77f023f8c7be7b',1,'plplotc.PL_FCI_WEIGHT()'],['../namespaceplplotc__fixed.html#a0c3257413c4d98f17bdf20939ce4ef87',1,'plplotc_fixed.PL_FCI_WEIGHT()']]],
  ['pl_5fhist_5fdefault',['PL_HIST_DEFAULT',['../classplplot.html#ae664ef65530eea52bb33d23e013436cf',1,'plplot::PL_HIST_DEFAULT()'],['../namespaceplplotc.html#a845525a70d0881cf4dee35d7a2dfbe0d',1,'plplotc.PL_HIST_DEFAULT()'],['../namespaceplplotc__fixed.html#a30e61250f2d0f203c9b3e26b952127d9',1,'plplotc_fixed.PL_HIST_DEFAULT()']]],
  ['pl_5fhist_5fignore_5foutliers',['PL_HIST_IGNORE_OUTLIERS',['../classplplot.html#a7303f4afaa30ab050b98415ccc078422',1,'plplot::PL_HIST_IGNORE_OUTLIERS()'],['../namespaceplplotc.html#a7cc56d537c892f81cffef2f8d4ee7958',1,'plplotc.PL_HIST_IGNORE_OUTLIERS()'],['../namespaceplplotc__fixed.html#a2a8da049df109e6854982bb59f3582c1',1,'plplotc_fixed.PL_HIST_IGNORE_OUTLIERS()']]],
  ['pl_5fhist_5fnoempty',['PL_HIST_NOEMPTY',['../classplplot.html#a6f5b48bed581eda8e674fde4eb0661d9',1,'plplot::PL_HIST_NOEMPTY()'],['../namespaceplplotc.html#acbcfe2e7e708cb029f1c97cc3a85926b',1,'plplotc.PL_HIST_NOEMPTY()'],['../namespaceplplotc__fixed.html#afe20c446f02fb80987a4e27ba4b57b65',1,'plplotc_fixed.PL_HIST_NOEMPTY()']]],
  ['pl_5fhist_5fnoexpand',['PL_HIST_NOEXPAND',['../classplplot.html#a05f2f5a4310eb2bb51bb24932eac95fc',1,'plplot::PL_HIST_NOEXPAND()'],['../namespaceplplotc.html#aabf92588e101123e2f89c4dbd8e36e90',1,'plplotc.PL_HIST_NOEXPAND()'],['../namespaceplplotc__fixed.html#ac86a07bfb47900630ff002507e1bdc97',1,'plplotc_fixed.PL_HIST_NOEXPAND()']]],
  ['pl_5fhist_5fnoscaling',['PL_HIST_NOSCALING',['../classplplot.html#ab094c5af4e566f29ffd5705d535c5e1f',1,'plplot::PL_HIST_NOSCALING()'],['../namespaceplplotc.html#a86292e97bfbef7878d6b68c564fe9381',1,'plplotc.PL_HIST_NOSCALING()'],['../namespaceplplotc__fixed.html#aa494b597aaef9a09c7788a3cfbcf3415',1,'plplotc_fixed.PL_HIST_NOSCALING()']]],
  ['pl_5finit',['pl_init',['../structPLDispatchTable.html#ac48230cf929c14238f77976b114cb8cf',1,'PLDispatchTable']]],
  ['pl_5flegend_5fbackground',['PL_LEGEND_BACKGROUND',['../classplplot.html#a3d75fe4de9052aacff7f5091025c04ed',1,'plplot::PL_LEGEND_BACKGROUND()'],['../namespaceplplotc.html#abc4a2e8a493084e9577ef11f4d62b208',1,'plplotc.PL_LEGEND_BACKGROUND()'],['../namespaceplplotc__fixed.html#a1113e4dc29efe076d929f7ab975b3eb3',1,'plplotc_fixed.PL_LEGEND_BACKGROUND()']]],
  ['pl_5flegend_5fbounding_5fbox',['PL_LEGEND_BOUNDING_BOX',['../classplplot.html#a3af5ae5127d1f51b3cdc65c01fc5e882',1,'plplot::PL_LEGEND_BOUNDING_BOX()'],['../namespaceplplotc.html#af601e258b515c6b07eab9c046f4d197e',1,'plplotc.PL_LEGEND_BOUNDING_BOX()'],['../namespaceplplotc__fixed.html#a6d0a73f554c54eaeabcfb888b3d3098b',1,'plplotc_fixed.PL_LEGEND_BOUNDING_BOX()']]],
  ['pl_5flegend_5fcolor_5fbox',['PL_LEGEND_COLOR_BOX',['../classplplot.html#a0a9f25fdc8fa51ec4582463fbdcc8872',1,'plplot::PL_LEGEND_COLOR_BOX()'],['../namespaceplplotc.html#a4b4963c66abfe6a3524bf1ce73a579a5',1,'plplotc.PL_LEGEND_COLOR_BOX()'],['../namespaceplplotc__fixed.html#a32466afa28f2c1c4ce4525b1ccd42b92',1,'plplotc_fixed.PL_LEGEND_COLOR_BOX()']]],
  ['pl_5flegend_5fline',['PL_LEGEND_LINE',['../classplplot.html#a5a6b51823871ef7424186349e3761898',1,'plplot::PL_LEGEND_LINE()'],['../namespaceplplotc.html#a6a5b7d6a12dcc9730aa2d09d04ca2f52',1,'plplotc.PL_LEGEND_LINE()'],['../namespaceplplotc__fixed.html#adb4ef91fa368c8c86bbc7eb1e9075207',1,'plplotc_fixed.PL_LEGEND_LINE()']]],
  ['pl_5flegend_5fnone',['PL_LEGEND_NONE',['../classplplot.html#afc67cad19f2ce126af591cfbea9c95b8',1,'plplot::PL_LEGEND_NONE()'],['../namespaceplplotc.html#aead30eae9759fe6e920f33f312a79aae',1,'plplotc.PL_LEGEND_NONE()'],['../namespaceplplotc__fixed.html#a82ff069fc151376de44e7af995db3ecf',1,'plplotc_fixed.PL_LEGEND_NONE()']]],
  ['pl_5flegend_5frow_5fmajor',['PL_LEGEND_ROW_MAJOR',['../classplplot.html#a8e7c02f62e023c437c39ca721db3da39',1,'plplot::PL_LEGEND_ROW_MAJOR()'],['../namespaceplplotc.html#ae7dffb9a57c39e4ac16aa729c2917221',1,'plplotc.PL_LEGEND_ROW_MAJOR()'],['../namespaceplplotc__fixed.html#ac04c9bb6c92d2836a3b16d6d6c71d25c',1,'plplotc_fixed.PL_LEGEND_ROW_MAJOR()']]],
  ['pl_5flegend_5fsymbol',['PL_LEGEND_SYMBOL',['../classplplot.html#a02e22aa6be1044324bbe070bef0d8654',1,'plplot::PL_LEGEND_SYMBOL()'],['../namespaceplplotc.html#ad845ed17a7e9050c76c224b3562bbd57',1,'plplotc.PL_LEGEND_SYMBOL()'],['../namespaceplplotc__fixed.html#abe87a74ce072ab33799513a9bf7a8da3',1,'plplotc_fixed.PL_LEGEND_SYMBOL()']]],
  ['pl_5flegend_5ftext_5fleft',['PL_LEGEND_TEXT_LEFT',['../classplplot.html#a698d5046d976c3901ed82da8c7c648e3',1,'plplot::PL_LEGEND_TEXT_LEFT()'],['../namespaceplplotc.html#a5bc571eac419099c60599e939ad4d714',1,'plplotc.PL_LEGEND_TEXT_LEFT()'],['../namespaceplplotc__fixed.html#aab96406ba71c099f38b4e59fe201fc72',1,'plplotc_fixed.PL_LEGEND_TEXT_LEFT()']]],
  ['pl_5fline',['pl_line',['../structPLDispatchTable.html#ac2cc0874ec01f042d5f4923e20bad80f',1,'PLDispatchTable']]],
  ['pl_5fmask_5falt',['PL_MASK_ALT',['../namespaceplplotc.html#a5c16c6a5e0164163319948ff43eff3a5',1,'plplotc.PL_MASK_ALT()'],['../namespaceplplotc__fixed.html#a171b6db0f291e2a071280b637b617e7e',1,'plplotc_fixed.PL_MASK_ALT()']]],
  ['pl_5fmask_5faltgr',['PL_MASK_ALTGR',['../namespaceplplotc.html#ae72856a78a24e3ff88778afec3af8f52',1,'plplotc.PL_MASK_ALTGR()'],['../namespaceplplotc__fixed.html#a225a41ae0629c27dade4fc6caf88de13',1,'plplotc_fixed.PL_MASK_ALTGR()']]],
  ['pl_5fmask_5fbutton1',['PL_MASK_BUTTON1',['../namespaceplplotc.html#aad9600deea050067c611857c2d95a2dc',1,'plplotc.PL_MASK_BUTTON1()'],['../namespaceplplotc__fixed.html#a1b8c23cd60efdfb23de54c5c1a6876cb',1,'plplotc_fixed.PL_MASK_BUTTON1()']]],
  ['pl_5fmask_5fbutton2',['PL_MASK_BUTTON2',['../namespaceplplotc.html#a6e47f218452efb91990ab2f5808a0227',1,'plplotc.PL_MASK_BUTTON2()'],['../namespaceplplotc__fixed.html#acef2413ca6e06dbe189db2bf12552421',1,'plplotc_fixed.PL_MASK_BUTTON2()']]],
  ['pl_5fmask_5fbutton3',['PL_MASK_BUTTON3',['../namespaceplplotc.html#a593727341168e39a2b49996ffc7e7647',1,'plplotc.PL_MASK_BUTTON3()'],['../namespaceplplotc__fixed.html#a9ec4ff666e29e26eb7029759dec0bb00',1,'plplotc_fixed.PL_MASK_BUTTON3()']]],
  ['pl_5fmask_5fbutton4',['PL_MASK_BUTTON4',['../namespaceplplotc.html#a36bd4cd410445f73e8f073282c0737fe',1,'plplotc.PL_MASK_BUTTON4()'],['../namespaceplplotc__fixed.html#a09ad8c99a45de8f5750dbe6f51a2e616',1,'plplotc_fixed.PL_MASK_BUTTON4()']]],
  ['pl_5fmask_5fbutton5',['PL_MASK_BUTTON5',['../namespaceplplotc.html#a8fb116984553291d09d9aaf944fbbdec',1,'plplotc.PL_MASK_BUTTON5()'],['../namespaceplplotc__fixed.html#af1a7d7cc54f0611fda217dbea3441138',1,'plplotc_fixed.PL_MASK_BUTTON5()']]],
  ['pl_5fmask_5fcaps',['PL_MASK_CAPS',['../namespaceplplotc.html#a61ef8c220c8ed12f4ebcadd3dda7d8fa',1,'plplotc.PL_MASK_CAPS()'],['../namespaceplplotc__fixed.html#aedf230b1ed3a3933b34ac7f5d0ef82ad',1,'plplotc_fixed.PL_MASK_CAPS()']]],
  ['pl_5fmask_5fcontrol',['PL_MASK_CONTROL',['../namespaceplplotc.html#aa4b34c5be475287b91d74781d333cab8',1,'plplotc.PL_MASK_CONTROL()'],['../namespaceplplotc__fixed.html#a8b66aaa26896771e068ea361738e7dea',1,'plplotc_fixed.PL_MASK_CONTROL()']]],
  ['pl_5fmask_5fnum',['PL_MASK_NUM',['../namespaceplplotc.html#addd78380df048a1096b1207b2cd2f9d3',1,'plplotc.PL_MASK_NUM()'],['../namespaceplplotc__fixed.html#a84cb0e7c3bbe5dd2e1cee054514ed60c',1,'plplotc_fixed.PL_MASK_NUM()']]],
  ['pl_5fmask_5fscroll',['PL_MASK_SCROLL',['../namespaceplplotc.html#ae66c6f83cee574dd53b9fe9d53bd6357',1,'plplotc.PL_MASK_SCROLL()'],['../namespaceplplotc__fixed.html#ab33d2a656e7c97f7885ea6ec6231b009',1,'plplotc_fixed.PL_MASK_SCROLL()']]],
  ['pl_5fmask_5fshift',['PL_MASK_SHIFT',['../namespaceplplotc.html#ab1b848a62c75c8f0e27275b06138042c',1,'plplotc.PL_MASK_SHIFT()'],['../namespaceplplotc__fixed.html#a6adf4ee26b8727f3a980be2d61f0e23b',1,'plplotc_fixed.PL_MASK_SHIFT()']]],
  ['pl_5fmask_5fwin',['PL_MASK_WIN',['../namespaceplplotc.html#a2d4cb90ec57ddb83976f382290420c31',1,'plplotc.PL_MASK_WIN()'],['../namespaceplplotc__fixed.html#ad516a999b2bafc9512f7a1b7bd1cf136',1,'plplotc_fixed.PL_MASK_WIN()']]],
  ['pl_5fmaxkey',['PL_MAXKEY',['../classplplot.html#a519a3647d4a9164a6c3448d75e467ee0',1,'plplot::PL_MAXKEY()'],['../namespaceplplotc.html#aee4112232cec089f90d4f7d92b4f0d86',1,'plplotc.PL_MAXKEY()'],['../namespaceplplotc__fixed.html#adccd42283cca9adfcce2ebbde405ce80',1,'plplotc_fixed.PL_MAXKEY()']]],
  ['pl_5fmaxwindows',['PL_MAXWINDOWS',['../classplplot.html#aaf6716db6f94369f85e4a3133b3c2f3f',1,'plplot::PL_MAXWINDOWS()'],['../namespaceplplotc.html#a779a1499d3588bc9c76e568ba2df3c32',1,'plplotc.PL_MAXWINDOWS()'],['../namespaceplplotc__fixed.html#a2db0c2ffb9faaf9f1fa88bc8c1a404cf',1,'plplotc_fixed.PL_MAXWINDOWS()']]],
  ['pl_5fmenustr',['pl_MenuStr',['../structPLDispatchTable.html#ad2f86ab958108b03d395110d84786aee',1,'PLDispatchTable']]],
  ['pl_5fnotset',['PL_NOTSET',['../classplplot.html#aa7eaae1c9ab27faf4ca609746c2d5f01',1,'plplot::PL_NOTSET()'],['../namespaceplplotc.html#aed76bc0c511df9cd6716ca28cbffe1a9',1,'plplotc.PL_NOTSET()'],['../namespaceplplotc__fixed.html#ae64e884cbb378b6d14bf0f874ec8b2cd',1,'plplotc_fixed.PL_NOTSET()']]],
  ['pl_5fopt_5farg',['PL_OPT_ARG',['../classplplot.html#a22de3264860e2ce779ab6d785eacebc0',1,'plplot::PL_OPT_ARG()'],['../namespaceplplotc.html#aaf00cc20965dced0e4123bed06e74d1e',1,'plplotc.PL_OPT_ARG()'],['../namespaceplplotc__fixed.html#a275e5cd3240a43831a8d6a12b9bf06a4',1,'plplotc_fixed.PL_OPT_ARG()']]],
  ['pl_5fopt_5fbool',['PL_OPT_BOOL',['../classplplot.html#a5b5a7d33258290b84d4b577aaab1c09d',1,'plplot::PL_OPT_BOOL()'],['../namespaceplplotc.html#a5e8f3261578b8694402e1f36d8ca1c7e',1,'plplotc.PL_OPT_BOOL()'],['../namespaceplplotc__fixed.html#ae28e05e43cff89f1866e1029932be0b4',1,'plplotc_fixed.PL_OPT_BOOL()']]],
  ['pl_5fopt_5fdisabled',['PL_OPT_DISABLED',['../classplplot.html#a4dd508fd67a2a8fa16520f2665e4319f',1,'plplot::PL_OPT_DISABLED()'],['../namespaceplplotc.html#abd6c285cf0ebb6c14039f0cafd8e401b',1,'plplotc.PL_OPT_DISABLED()'],['../namespaceplplotc__fixed.html#a77e002aa17527472b59fa4360edc9bcf',1,'plplotc_fixed.PL_OPT_DISABLED()']]],
  ['pl_5fopt_5fenabled',['PL_OPT_ENABLED',['../classplplot.html#a3f2a30bd2e6f79b41fa25570251d162a',1,'plplot::PL_OPT_ENABLED()'],['../namespaceplplotc.html#ac02ececdcc757965e88a276bd64df715',1,'plplotc.PL_OPT_ENABLED()'],['../namespaceplplotc__fixed.html#a3d47902548abf36ecb00b0fce2033662',1,'plplotc_fixed.PL_OPT_ENABLED()']]],
  ['pl_5fopt_5ffloat',['PL_OPT_FLOAT',['../classplplot.html#a214eb94c19b123881ea133e15b1e58fe',1,'plplot::PL_OPT_FLOAT()'],['../namespaceplplotc.html#a96772303c09747ebd4a5b97113497771',1,'plplotc.PL_OPT_FLOAT()'],['../namespaceplplotc__fixed.html#a1b3a8c0915adae8a664754fa752b7b0d',1,'plplotc_fixed.PL_OPT_FLOAT()']]],
  ['pl_5fopt_5ffunc',['PL_OPT_FUNC',['../classplplot.html#a5f56a02a4fb93427ab66e0a72b9a9d8e',1,'plplot::PL_OPT_FUNC()'],['../namespaceplplotc.html#a8243ce1acc41ce3a9c6a0a70d3ad6525',1,'plplotc.PL_OPT_FUNC()'],['../namespaceplplotc__fixed.html#a4878e4b9fe89bb4530412517a45f796d',1,'plplotc_fixed.PL_OPT_FUNC()']]],
  ['pl_5fopt_5fint',['PL_OPT_INT',['../classplplot.html#a8980554346127a400d0fb905931a3889',1,'plplot::PL_OPT_INT()'],['../namespaceplplotc.html#ac5d4da34148933be221174c149277220',1,'plplotc.PL_OPT_INT()'],['../namespaceplplotc__fixed.html#a331594b2215e2bb935d5a8ad50743eb5',1,'plplotc_fixed.PL_OPT_INT()']]],
  ['pl_5fopt_5finvisible',['PL_OPT_INVISIBLE',['../classplplot.html#a6c63bb867085cd87302922ca7d205056',1,'plplot::PL_OPT_INVISIBLE()'],['../namespaceplplotc.html#a44a1e35b8c895002867f93fc163fee29',1,'plplotc.PL_OPT_INVISIBLE()'],['../namespaceplplotc__fixed.html#a67f2c5d90166db384d5ace17bcebec46',1,'plplotc_fixed.PL_OPT_INVISIBLE()']]],
  ['pl_5fopt_5fnodelete',['PL_OPT_NODELETE',['../classplplot.html#a42f883ffb80065fa19774f554b8c1e6f',1,'plplot::PL_OPT_NODELETE()'],['../namespaceplplotc.html#a1496de58bd6272dee9f8373f551b377c',1,'plplotc.PL_OPT_NODELETE()'],['../namespaceplplotc__fixed.html#a14184018c970951a30a3886fb680ffd6',1,'plplotc_fixed.PL_OPT_NODELETE()']]],
  ['pl_5fopt_5fstring',['PL_OPT_STRING',['../classplplot.html#a44533ceab40f92f02a4fd1cde7afc2d4',1,'plplot::PL_OPT_STRING()'],['../namespaceplplotc.html#afc6c6d9d92c1b411d0d578599666b51e',1,'plplotc.PL_OPT_STRING()'],['../namespaceplplotc__fixed.html#ad7b5625f34bd286c1708710eb338f9e1',1,'plplotc_fixed.PL_OPT_STRING()']]],
  ['pl_5fparse_5ffull',['PL_PARSE_FULL',['../classplplot.html#a261101736f21924ec80e254b63258304',1,'plplot::PL_PARSE_FULL()'],['../namespaceplplotc.html#aa88dd5322e244335e99a41d9ef881698',1,'plplotc.PL_PARSE_FULL()'],['../namespaceplplotc__fixed.html#a6379f728658851233cdc8e96239c6357',1,'plplotc_fixed.PL_PARSE_FULL()']]],
  ['pl_5fparse_5fnodash',['PL_PARSE_NODASH',['../classplplot.html#ab396b3c8123fa19eeb649a175175c032',1,'plplot::PL_PARSE_NODASH()'],['../namespaceplplotc.html#aff2af8dffef5de6dbcdecc701f03d5af',1,'plplotc.PL_PARSE_NODASH()'],['../namespaceplplotc__fixed.html#a6354b61fa40e25dcaeaa3608ed61f070',1,'plplotc_fixed.PL_PARSE_NODASH()']]],
  ['pl_5fparse_5fnodelete',['PL_PARSE_NODELETE',['../classplplot.html#a9891ed6cce9b02ce103a01bc88f4484d',1,'plplot::PL_PARSE_NODELETE()'],['../namespaceplplotc.html#ac066b1e47e6b44cd79eac4ea3be39ed3',1,'plplotc.PL_PARSE_NODELETE()'],['../namespaceplplotc__fixed.html#ae34cc858dac01d8dd87ee632f6717773',1,'plplotc_fixed.PL_PARSE_NODELETE()']]],
  ['pl_5fparse_5fnoprogram',['PL_PARSE_NOPROGRAM',['../classplplot.html#acb62e30faebb753535ee8c24f9d37b6b',1,'plplot::PL_PARSE_NOPROGRAM()'],['../namespaceplplotc.html#a25c0d78bfe8bc79a147650563750465a',1,'plplotc.PL_PARSE_NOPROGRAM()'],['../namespaceplplotc__fixed.html#a3291a055d7205271db6ec622b48cf43f',1,'plplotc_fixed.PL_PARSE_NOPROGRAM()']]],
  ['pl_5fparse_5foverride',['PL_PARSE_OVERRIDE',['../classplplot.html#af7487079ed393ed63fe54a0f951ead16',1,'plplot::PL_PARSE_OVERRIDE()'],['../namespaceplplotc.html#a496639e6132709a0dd24849413a4deef',1,'plplotc.PL_PARSE_OVERRIDE()'],['../namespaceplplotc__fixed.html#a5ed9ac3245ea01bb113b25f4f7b7d589',1,'plplotc_fixed.PL_PARSE_OVERRIDE()']]],
  ['pl_5fparse_5fpartial',['PL_PARSE_PARTIAL',['../classplplot.html#afea2ee06309d8a1592e023fa7052e1ef',1,'plplot::PL_PARSE_PARTIAL()'],['../namespaceplplotc.html#a0d93f43441998f2de93036815020f71a',1,'plplotc.PL_PARSE_PARTIAL()'],['../namespaceplplotc__fixed.html#a65aa198110f7bcc87abfab990b0e4ab2',1,'plplotc_fixed.PL_PARSE_PARTIAL()']]],
  ['pl_5fparse_5fquiet',['PL_PARSE_QUIET',['../classplplot.html#ab26442732ed6e2042b36b8af25d9a649',1,'plplot::PL_PARSE_QUIET()'],['../namespaceplplotc.html#a4467ee661a8937b1f879a751eeeeadc3',1,'plplotc.PL_PARSE_QUIET()'],['../namespaceplplotc__fixed.html#a1b2a3fa0f34f5ed64fef9fd7061a1faf',1,'plplotc_fixed.PL_PARSE_QUIET()']]],
  ['pl_5fparse_5fshowall',['PL_PARSE_SHOWALL',['../classplplot.html#a7f5a7d45f9e7add01640b4e708293667',1,'plplot::PL_PARSE_SHOWALL()'],['../namespaceplplotc.html#aa8690112cb60dbe018f43a2a3c29fdbc',1,'plplotc.PL_PARSE_SHOWALL()'],['../namespaceplplotc__fixed.html#aeadd8667ad0f30c27b2fb44425524aee',1,'plplotc_fixed.PL_PARSE_SHOWALL()']]],
  ['pl_5fparse_5fskip',['PL_PARSE_SKIP',['../classplplot.html#aadfee6aca3a9ce1222524f84b979e5f8',1,'plplot::PL_PARSE_SKIP()'],['../namespaceplplotc.html#a93ea921c3ed513199ab81a93ac6a460d',1,'plplotc.PL_PARSE_SKIP()'],['../namespaceplplotc__fixed.html#aea45f53b5e40d87553803776fd41d511',1,'plplotc_fixed.PL_PARSE_SKIP()']]],
  ['pl_5fpolyline',['pl_polyline',['../structPLDispatchTable.html#a827caa159faf9dbed59ca1f09eb536f4',1,'PLDispatchTable']]],
  ['pl_5fposition_5fbottom',['PL_POSITION_BOTTOM',['../classplplot.html#a1d1c007d4c2142a8641b088cd09a876d',1,'plplot::PL_POSITION_BOTTOM()'],['../namespaceplplotc.html#a8a72b5e17704c55222b3c67125e321bd',1,'plplotc.PL_POSITION_BOTTOM()'],['../namespaceplplotc__fixed.html#a1c6f25e9ef605302331db91165e36ae6',1,'plplotc_fixed.PL_POSITION_BOTTOM()']]],
  ['pl_5fposition_5finside',['PL_POSITION_INSIDE',['../classplplot.html#a62c4aae58e473a0a2d932a9f53265260',1,'plplot::PL_POSITION_INSIDE()'],['../namespaceplplotc.html#a9fed591aa8a475128add157fff0e5fde',1,'plplotc.PL_POSITION_INSIDE()'],['../namespaceplplotc__fixed.html#a3e0eff830102a454cfd036b6c5d1b718',1,'plplotc_fixed.PL_POSITION_INSIDE()']]],
  ['pl_5fposition_5fleft',['PL_POSITION_LEFT',['../classplplot.html#abac10a1448047081f317570f1218fc39',1,'plplot::PL_POSITION_LEFT()'],['../namespaceplplotc.html#a0d3481596075477e2d0ef8a20e608d6b',1,'plplotc.PL_POSITION_LEFT()'],['../namespaceplplotc__fixed.html#a997a4eae3cb4909c22d397007982508b',1,'plplotc_fixed.PL_POSITION_LEFT()']]],
  ['pl_5fposition_5foutside',['PL_POSITION_OUTSIDE',['../classplplot.html#a80f6536884b018ed6a6399e242c11832',1,'plplot::PL_POSITION_OUTSIDE()'],['../namespaceplplotc.html#ad963a64f3db3c6784e98f2b0d9a69cd5',1,'plplotc.PL_POSITION_OUTSIDE()'],['../namespaceplplotc__fixed.html#a40201a56d799f48e4b862c2fbfebf44a',1,'plplotc_fixed.PL_POSITION_OUTSIDE()']]],
  ['pl_5fposition_5fright',['PL_POSITION_RIGHT',['../classplplot.html#a6eab4aca6ab601078b3922e67321e405',1,'plplot::PL_POSITION_RIGHT()'],['../namespaceplplotc.html#a0b31589c970ace749e230d4e4f8b2f8e',1,'plplotc.PL_POSITION_RIGHT()'],['../namespaceplplotc__fixed.html#a58c28455225eb9bb85cff8572e03b5bc',1,'plplotc_fixed.PL_POSITION_RIGHT()']]],
  ['pl_5fposition_5fsubpage',['PL_POSITION_SUBPAGE',['../classplplot.html#aa5b4c0a51c3a51687f21f57018d162b0',1,'plplot::PL_POSITION_SUBPAGE()'],['../namespaceplplotc.html#a4fb867b72c453a2a11c8ba032f13489f',1,'plplotc.PL_POSITION_SUBPAGE()'],['../namespaceplplotc__fixed.html#a82408cc192fd073b466722e0b7cfd751',1,'plplotc_fixed.PL_POSITION_SUBPAGE()']]],
  ['pl_5fposition_5ftop',['PL_POSITION_TOP',['../classplplot.html#ad2b8fb43049ae5a9515f6c5de7b2a249',1,'plplot::PL_POSITION_TOP()'],['../namespaceplplotc.html#a0abd0e9822ad69dbfb0aa3dff1792108',1,'plplotc.PL_POSITION_TOP()'],['../namespaceplplotc__fixed.html#aa45f9ef962dc03502557410b44a6d489',1,'plplotc_fixed.PL_POSITION_TOP()']]],
  ['pl_5fposition_5fviewport',['PL_POSITION_VIEWPORT',['../classplplot.html#afdb08ad07520cbae622ca660e4e39c92',1,'plplot::PL_POSITION_VIEWPORT()'],['../namespaceplplotc.html#a4d5ed12522251a89cef03d18fd5bfcda',1,'plplotc.PL_POSITION_VIEWPORT()'],['../namespaceplplotc__fixed.html#a3000941f57471b2ac33bb17c80f7ae7a',1,'plplotc_fixed.PL_POSITION_VIEWPORT()']]],
  ['pl_5fseq',['pl_seq',['../structPLDispatchTable.html#a177de68ffe84a6937dfdb5674db57fba',1,'PLDispatchTable']]],
  ['pl_5fsetcontlabelformat',['pl_setcontlabelformat',['../classplplot.html#a4bb455a23067a0a31054fbbd2df9a803',1,'plplot::pl_setcontlabelformat()'],['../tclgen__s_8h.html#aa36e1d0e71e128500ad1614f5b530954',1,'pl_setcontlabelformat():&#160;tclgen_s.h']]],
  ['pl_5fsetcontlabelformatcmd',['pl_setcontlabelformatCmd',['../tclgen__s_8h.html#a569c9277edbf96d6553ef5f91520a5d4',1,'tclgen_s.h']]],
  ['pl_5fsetcontlabelparam',['pl_setcontlabelparam',['../classplplot.html#a67f9326e173007cd7320aa90afc682a4',1,'plplot']]],
  ['pl_5fstate',['pl_state',['../structPLDispatchTable.html#a84d2eadabcdd1a97f46d530f167dc3b9',1,'PLDispatchTable']]],
  ['pl_5ftest_5fflt',['pl_test_flt',['../classplplot.html#aa8a085057363aec3c1f87b6201b6dc6e',1,'plplot']]],
  ['pl_5ftidy',['pl_tidy',['../structPLDispatchTable.html#ab0f554e20c4dcb1ec7af9da5f139fed8',1,'PLDispatchTable']]],
  ['pl_5ftype',['pl_type',['../structPLDispatchTable.html#a6960c21f5b51bdda75ebfa283d5b1d1e',1,'PLDispatchTable']]],
  ['pl_5fwait',['pl_wait',['../structPLDispatchTable.html#a7c6a59fcd585e91a615e0cc536b3843f',1,'PLDispatchTable']]],
  ['pl_5fx_5faxis',['PL_X_AXIS',['../classplplot.html#a9c778b860f2871a585009497787919e6',1,'plplot::PL_X_AXIS()'],['../namespaceplplotc.html#a8aa8ffa99953ead9bfb1f6325278ffac',1,'plplotc.PL_X_AXIS()'],['../namespaceplplotc__fixed.html#a0d130887120f7b0d32ecd1ae8a20bbf7',1,'plplotc_fixed.PL_X_AXIS()']]],
  ['pl_5fy_5faxis',['PL_Y_AXIS',['../classplplot.html#ae2114d3d365951b2982495ea8c5d74bc',1,'plplot::PL_Y_AXIS()'],['../namespaceplplotc.html#aec4a4c625c8cbdface2c1502a4d54417',1,'plplotc.PL_Y_AXIS()'],['../namespaceplplotc__fixed.html#a4e3a6a6acbd261ff9641e9ddb72174b8',1,'plplotc_fixed.PL_Y_AXIS()']]],
  ['pl_5fz_5faxis',['PL_Z_AXIS',['../classplplot.html#a3db3b59a6a597a00ad7d5e3cd8189e6c',1,'plplot::PL_Z_AXIS()'],['../namespaceplplotc.html#ab38e608332e8694686898c0e7384e1b3',1,'plplotc.PL_Z_AXIS()'],['../namespaceplplotc__fixed.html#a52342f55be732d38cf0dd7f662ae01fe',1,'plplotc_fixed.PL_Z_AXIS()']]],
  ['pladv',['pladv',['../classplplot.html#ad4160f178ade6ce47ddf69113ca8a1d6',1,'plplot']]],
  ['plarc',['plarc',['../classplplot.html#a3a3d8a53fd056ab44f8318b96dc707f5',1,'plplot']]],
  ['plbool',['PLBOOL',['../classplplot.html#aed3a1ce8dd8ffdd4cc49a02a91185eca',1,'plplot']]],
  ['plbop',['plbop',['../classplplot.html#a14a6d89255e518170eec470678a22cbe',1,'plplot']]],
  ['plbtime',['plbtime',['../classplplot.html#a6dce74122c4fedafd5dcd365757f7fdd',1,'plplot']]],
  ['plbuf_5fbuffer',['plbuf_buffer',['../struct__state.html#a3e109f94028a2f8e1c77fcb5e08e1419',1,'_state::plbuf_buffer()'],['../structPLStream.html#a3f789e83127b6787146a9dace61718b6',1,'PLStream::plbuf_buffer()']]],
  ['plbuf_5fbuffer_5fgrow',['plbuf_buffer_grow',['../structPLStream.html#a1c3a8a26949c652d62c75025d0f51d0a',1,'PLStream']]],
  ['plbuf_5fbuffer_5fsize',['plbuf_buffer_size',['../struct__state.html#a8ba193a6f1b9d24d4a2b1a84b0ebee02',1,'_state::plbuf_buffer_size()'],['../structPLStream.html#ab9e36ad9df32802d429079a114dfecfc',1,'PLStream::plbuf_buffer_size()']]],
  ['plbuf_5fread',['plbuf_read',['../structPLStream.html#abb5e658588313b632a4bfc7a315fc0ec',1,'PLStream']]],
  ['plbuf_5freadpos',['plbuf_readpos',['../struct__state.html#a9a8f79675121404abef6de4a754a5583',1,'_state::plbuf_readpos()'],['../structPLStream.html#a34c602d26ca76033d069d17587b854d6',1,'PLStream::plbuf_readpos()']]],
  ['plbuf_5ftop',['plbuf_top',['../struct__state.html#a855b9fc8275e51f42ca108dc6b69a28d',1,'_state::plbuf_top()'],['../structPLStream.html#a347f9faac2e393dd04e04d1efa45eac3',1,'PLStream::plbuf_top()']]],
  ['plbuf_5fwrite',['plbuf_write',['../structPLStream.html#a5bb8768ffd553799be633be3ab70d915',1,'PLStream']]],
  ['plbufferingcb',['PLBufferingCB',['../classplplot.html#a63efafe2f195046ea5cea3d3ad0177b2',1,'plplot']]],
  ['plbufowner',['plbufOwner',['../structPLStream.html#aff218e325ec246a09fccdf84083462db',1,'PLStream']]],
  ['plcalc_5fworld',['plcalc_world',['../classplplot.html#a360056f26a247b8ad2b465508184ea89',1,'plplot']]],
  ['plclear',['plclear',['../classplplot.html#a324f6b1aa925cd0e6ee324005a56e4ad',1,'plplot']]],
  ['plclearopts',['plClearOpts',['../namespaceplplotc.html#a3b5a47229240d9a24ca61397dd0569c2',1,'plplotc.plClearOpts()'],['../namespaceplplotc__fixed.html#a11fec67df9076577eeb7ac5b287a1326',1,'plplotc_fixed.plClearOpts()']]],
  ['plclr',['plclr',['../classplplot.html#ada9a848fca721868333e62f4f50cb795',1,'plplot']]],
  ['plcol',['plcol',['../classplplot.html#adf04c40ccc1f4afe203c8dc22f559db3',1,'plplot']]],
  ['plcol0',['plcol0',['../classplplot.html#a36709a68bd249d75667545fadfacce56',1,'plplot']]],
  ['plcol1',['plcol1',['../classplplot.html#a80d9e51c207e539752c5c6a3e190d0e9',1,'plplot']]],
  ['plcolor',['PLColor',['../classplplot.html#ad775c203b72279b0eea580058f769227',1,'plplot']]],
  ['plconfigtime',['plconfigtime',['../classplplot.html#a8f20a70ffb4bd540604f03162a2e6c2b',1,'plplot']]],
  ['plcontf',['plcontf',['../classplplot.html#a947d6130c7bab75db0de9a942dbf9737',1,'plplot']]],
  ['plcontrolpt',['PLControlPt',['../classplplot.html#a0630fe0def05bf5565fa3d01a47eb377',1,'plplot']]],
  ['plcpstrm',['plcpstrm',['../classplplot.html#a5dae076c6e23c9a0d6b1fcf87d1077cf',1,'plplot']]],
  ['plctime',['plctime',['../classplplot.html#a8bebeb7b4242f3ce6c6942cc9987c465',1,'plplot']]],
  ['pld_5fdevice_5finfo_5faqt',['plD_DEVICE_INFO_aqt',['../aqt_8c.html#a08065bc229dbb1edf1300dc55507766b',1,'aqt.c']]],
  ['pld_5fdevice_5finfo_5fcairo',['plD_DEVICE_INFO_cairo',['../cairo_8c.html#a5059cfa495a021b6533d96f8a1bfef45',1,'cairo.c']]],
  ['pld_5fdevice_5finfo_5fsvg',['plD_DEVICE_INFO_svg',['../svg_8c.html#a5e2e3ccd562e3f4571c9a473594387e1',1,'svg.c']]],
  ['pld_5fdevice_5finfo_5fwxwidgets',['plD_DEVICE_INFO_wxwidgets',['../wxwidgets_8cpp.html#aadc0641db8a8b555b1e2f2e97378d02e',1,'wxwidgets.cpp']]],
  ['pldis',['pldis',['../structPlFrame.html#aff05fed4c4aef0cce0e43b4814912890',1,'PlFrame::pldis()'],['../structPlPlotter.html#a14ef29bd844f978324287c2f3a8495e6',1,'PlPlotter::pldis()']]],
  ['pldisplay',['PLDisplay',['../classplplot.html#a348066e61ef5851261cbff823248aaaa',1,'plplot']]],
  ['plend',['plend',['../classplplot.html#a206a3acff23238c0da8009b7a6d26352',1,'plplot']]],
  ['plend1',['plend1',['../classplplot.html#af0def8ece24e4606f9b58ae67438a61e',1,'plplot']]],
  ['plenv',['plenv',['../classplplot.html#a661a84dd8e8131c127dbbe63aedee622',1,'plplot']]],
  ['plenv0',['plenv0',['../classplplot.html#a8f1909ae19cdaaf7e589ad93098c6c0b',1,'plplot']]],
  ['pleop',['pleop',['../classplplot.html#aadd0938b4b4299dbef38ed97213c44dc',1,'plplot']]],
  ['plesc_5falloc_5fncol',['PLESC_ALLOC_NCOL',['../classplplot.html#a2979bf621b0b9dee428474471c7b4b03',1,'plplot::PLESC_ALLOC_NCOL()'],['../namespaceplplotc.html#af5019f03e5604c1591d4d3ecef40417a',1,'plplotc.PLESC_ALLOC_NCOL()'],['../namespaceplplotc__fixed.html#a381e9b17efa7dd41ea4d3c1a83b96ca0',1,'plplotc_fixed.PLESC_ALLOC_NCOL()']]],
  ['plesc_5fappend_5fbuffer',['PLESC_APPEND_BUFFER',['../namespaceplplotc.html#a3c1b5742671c7991e48b411268807b40',1,'plplotc.PLESC_APPEND_BUFFER()'],['../namespaceplplotc__fixed.html#aeb30875ca5bf8a957b89cd6325bf7b21',1,'plplotc_fixed.PLESC_APPEND_BUFFER()']]],
  ['plesc_5farc',['PLESC_ARC',['../namespaceplplotc.html#a88c9dd3a5c5c4ff2900db7a7ee815d69',1,'plplotc.PLESC_ARC()'],['../namespaceplplotc__fixed.html#a81cb2e3477cb7c43be32a75923c0fc1d',1,'plplotc_fixed.PLESC_ARC()']]],
  ['plesc_5fbegin_5ftext',['PLESC_BEGIN_TEXT',['../namespaceplplotc.html#aafa90b4565f0f69e93351cba71598990',1,'plplotc.PLESC_BEGIN_TEXT()'],['../namespaceplplotc__fixed.html#a42b101ac57dfbd32ef6858eeeb550ea5',1,'plplotc_fixed.PLESC_BEGIN_TEXT()']]],
  ['plesc_5fclear',['PLESC_CLEAR',['../classplplot.html#a21fee60e87ed0dc7242db6c3d8841d62',1,'plplot::PLESC_CLEAR()'],['../namespaceplplotc.html#a876cf74842ce228ee028a8106c825cce',1,'plplotc.PLESC_CLEAR()'],['../namespaceplplotc__fixed.html#a71715cb3ee37d1be4ad0da4f46c9d1f9',1,'plplotc_fixed.PLESC_CLEAR()']]],
  ['plesc_5fcontrol_5fchar',['PLESC_CONTROL_CHAR',['../namespaceplplotc.html#a98d1b2377be5102740d2b3b76af18f7d',1,'plplotc.PLESC_CONTROL_CHAR()'],['../namespaceplplotc__fixed.html#a4de8f027f56d638a8010571652f9a76e',1,'plplotc_fixed.PLESC_CONTROL_CHAR()']]],
  ['plesc_5fdash',['PLESC_DASH',['../classplplot.html#a491c412ec528c6ff3ea856939c335590',1,'plplot::PLESC_DASH()'],['../namespaceplplotc.html#a1df41bbf8effa531f0d1fdfc2325e8e7',1,'plplotc.PLESC_DASH()'],['../namespaceplplotc__fixed.html#af10baffbb7f23ae7f521eb8383a3a558',1,'plplotc_fixed.PLESC_DASH()']]],
  ['plesc_5fdev2plcol',['PLESC_DEV2PLCOL',['../classplplot.html#a52cae4e01a1a75f7cb601dd0f7a56b71',1,'plplot::PLESC_DEV2PLCOL()'],['../namespaceplplotc.html#ab34b545559e6fc12ddb7d9505e32d22f',1,'plplotc.PLESC_DEV2PLCOL()'],['../namespaceplplotc__fixed.html#ae71724b68e77ef4f71b9013ce5c8d803',1,'plplotc_fixed.PLESC_DEV2PLCOL()']]],
  ['plesc_5fdevinit',['PLESC_DEVINIT',['../classplplot.html#a5903b77b5247beadbb6c1074134d8501',1,'plplot::PLESC_DEVINIT()'],['../namespaceplplotc.html#aa215fe460d2699f9c0ae02fa51b13f43',1,'plplotc.PLESC_DEVINIT()'],['../namespaceplplotc__fixed.html#a26190c62e0c27384e2df3be1a779b5e6',1,'plplotc_fixed.PLESC_DEVINIT()']]],
  ['plesc_5fdi',['PLESC_DI',['../classplplot.html#a0299a17812a13b6648e974a76fe820aa',1,'plplot::PLESC_DI()'],['../namespaceplplotc.html#a3b826bbf936c421419d798faa46dc584',1,'plplotc.PLESC_DI()'],['../namespaceplplotc__fixed.html#aa06432774c18d6c0c30fff9890c17682',1,'plplotc_fixed.PLESC_DI()']]],
  ['plesc_5fdoublebuffering',['PLESC_DOUBLEBUFFERING',['../classplplot.html#a7964872238c50644f358d43c9d603a44',1,'plplot::PLESC_DOUBLEBUFFERING()'],['../namespaceplplotc.html#aab012aabef62dba42e2a0d58ed0b6f0d',1,'plplotc.PLESC_DOUBLEBUFFERING()'],['../namespaceplplotc__fixed.html#a482546b432820873fbce443c4e00a688',1,'plplotc_fixed.PLESC_DOUBLEBUFFERING()']]],
  ['plesc_5fdoublebuffering_5fdisable',['PLESC_DOUBLEBUFFERING_DISABLE',['../classplplot.html#ab1f1ac3baa47a089d514e163c79cacec',1,'plplot::PLESC_DOUBLEBUFFERING_DISABLE()'],['../namespaceplplotc.html#ac62d2827edd6f5b51a16b3ccd95e9c0c',1,'plplotc.PLESC_DOUBLEBUFFERING_DISABLE()'],['../namespaceplplotc__fixed.html#a1aaa97ad6795c6047b489a5e1db29178',1,'plplotc_fixed.PLESC_DOUBLEBUFFERING_DISABLE()']]],
  ['plesc_5fdoublebuffering_5fenable',['PLESC_DOUBLEBUFFERING_ENABLE',['../classplplot.html#a22554c3a2e252e794f942b497736a0d4',1,'plplot::PLESC_DOUBLEBUFFERING_ENABLE()'],['../namespaceplplotc.html#a1e75cfe296046477e9ac7c4d67c28c26',1,'plplotc.PLESC_DOUBLEBUFFERING_ENABLE()'],['../namespaceplplotc__fixed.html#a4363c1430e49f5823c1c65d59b96890a',1,'plplotc_fixed.PLESC_DOUBLEBUFFERING_ENABLE()']]],
  ['plesc_5fdoublebuffering_5fquery',['PLESC_DOUBLEBUFFERING_QUERY',['../classplplot.html#af5317b273220e599a6ebb217b0b75a94',1,'plplot::PLESC_DOUBLEBUFFERING_QUERY()'],['../namespaceplplotc.html#ae6b5e6b02baa32afdaac6c1e8d2f236e',1,'plplotc.PLESC_DOUBLEBUFFERING_QUERY()'],['../namespaceplplotc__fixed.html#aa42f492730cc1e243179f1a192cf2b77',1,'plplotc_fixed.PLESC_DOUBLEBUFFERING_QUERY()']]],
  ['plesc_5feh',['PLESC_EH',['../classplplot.html#a2521683da2a6317d0522345656c06c30',1,'plplot::PLESC_EH()'],['../namespaceplplotc.html#a195e11c9ce77a2bbab16767d008b111f',1,'plplotc.PLESC_EH()'],['../namespaceplplotc__fixed.html#ab42519ea5930a94d443f39785e279b65',1,'plplotc_fixed.PLESC_EH()']]],
  ['plesc_5fend_5frasterize',['PLESC_END_RASTERIZE',['../namespaceplplotc.html#ab910687e7e7afadd653db3f4d48b148e',1,'plplotc.PLESC_END_RASTERIZE()'],['../namespaceplplotc__fixed.html#ab8e02eb6fe92e3fdb0aa7660bce16da7',1,'plplotc_fixed.PLESC_END_RASTERIZE()']]],
  ['plesc_5fend_5ftext',['PLESC_END_TEXT',['../namespaceplplotc.html#a6029ac27c7ef2a0e783ca0cb5635e477',1,'plplotc.PLESC_END_TEXT()'],['../namespaceplplotc__fixed.html#afc9104242e1412752ea54c4f402df306',1,'plplotc_fixed.PLESC_END_TEXT()']]],
  ['plesc_5fexpose',['PLESC_EXPOSE',['../classplplot.html#a0b1fe72940429950c12cd26be519e84b',1,'plplot::PLESC_EXPOSE()'],['../namespaceplplotc.html#ae38e7b767f85ab19c019a2c739cc7761',1,'plplotc.PLESC_EXPOSE()'],['../namespaceplplotc__fixed.html#aada7b79d8997f1a96cf5c36b498971b3',1,'plplotc_fixed.PLESC_EXPOSE()']]],
  ['plesc_5ffill',['PLESC_FILL',['../classplplot.html#a20c11e1f55c5dc2cab61af574b65bd1c',1,'plplot::PLESC_FILL()'],['../namespaceplplotc.html#a0161658227f3be0036ce2be29b831977',1,'plplotc.PLESC_FILL()'],['../namespaceplplotc__fixed.html#a221e4f8f73f9dce19e77c42d57a4fc24',1,'plplotc_fixed.PLESC_FILL()']]],
  ['plesc_5ffixaspect',['PLESC_FIXASPECT',['../namespaceplplotc.html#ab30919de5123e4ff1faeb71651cab801',1,'plplotc.PLESC_FIXASPECT()'],['../namespaceplplotc__fixed.html#a2c7fef545f17e4b87efaa96751847f41',1,'plplotc_fixed.PLESC_FIXASPECT()']]],
  ['plesc_5fflush',['PLESC_FLUSH',['../classplplot.html#aae67edbc2f85e1d916a2a1c316669642',1,'plplot::PLESC_FLUSH()'],['../namespaceplplotc.html#aae31cc0d750e429823e7722a4c629edc',1,'plplotc.PLESC_FLUSH()'],['../namespaceplplotc__fixed.html#a1cb588741cd0c1e5d8fdd8a3ca603097',1,'plplotc_fixed.PLESC_FLUSH()']]],
  ['plesc_5fflush_5fremaining_5fbuffer',['PLESC_FLUSH_REMAINING_BUFFER',['../namespaceplplotc.html#aafb7d40ef560973c189bd1af7ea51cad',1,'plplotc.PLESC_FLUSH_REMAINING_BUFFER()'],['../namespaceplplotc__fixed.html#ad4602ff0cdc6f41e63dd3daeef2d1002',1,'plplotc_fixed.PLESC_FLUSH_REMAINING_BUFFER()']]],
  ['plesc_5fgetbackend',['PLESC_GETBACKEND',['../namespaceplplotc.html#afe5bfb8be365234aef2097a735c35744',1,'plplotc.PLESC_GETBACKEND()'],['../namespaceplplotc__fixed.html#a0e536d809949838c30e088c4f663898a',1,'plplotc_fixed.PLESC_GETBACKEND()']]],
  ['plesc_5fgetc',['PLESC_GETC',['../classplplot.html#a4faa897aeb746b0025dda6037574571a',1,'plplot::PLESC_GETC()'],['../namespaceplplotc.html#a19d4d2d2836911342deb0281d2e24059',1,'plplotc.PLESC_GETC()'],['../namespaceplplotc__fixed.html#aedad2334e3cb99cf7430ae14f6923617',1,'plplotc_fixed.PLESC_GETC()']]],
  ['plesc_5fgradient',['PLESC_GRADIENT',['../namespaceplplotc.html#aacf6b5fe12c4d85313aa861dfa3b84e7',1,'plplotc.PLESC_GRADIENT()'],['../namespaceplplotc__fixed.html#a7dbb8af4e1151fadd91856c31a61282c',1,'plplotc_fixed.PLESC_GRADIENT()']]],
  ['plesc_5fgraph',['PLESC_GRAPH',['../classplplot.html#a24a4bd3a1038035154a7bc5cbe284cdd',1,'plplot::PLESC_GRAPH()'],['../namespaceplplotc.html#a23db208de6ec19317b2f5f7e50304537',1,'plplotc.PLESC_GRAPH()'],['../namespaceplplotc__fixed.html#a0760a9949bc5ddec206612e89183d6c8',1,'plplotc_fixed.PLESC_GRAPH()']]],
  ['plesc_5fhas_5ftext',['PLESC_HAS_TEXT',['../classplplot.html#a714a6de0bc30ecca7c16eb3cb57a8705',1,'plplot::PLESC_HAS_TEXT()'],['../namespaceplplotc.html#af5c0c3836b5e1581d3be64ef852cb13f',1,'plplotc.PLESC_HAS_TEXT()'],['../namespaceplplotc__fixed.html#a082f66ce6b81d62f52f8c419a7cb37af',1,'plplotc_fixed.PLESC_HAS_TEXT()']]],
  ['plesc_5fimage',['PLESC_IMAGE',['../classplplot.html#aa2d5257121ceac78b398591611f6922a',1,'plplot::PLESC_IMAGE()'],['../namespaceplplotc.html#a7b8b082fd76f82e745e7c0495a50879e',1,'plplotc.PLESC_IMAGE()'],['../namespaceplplotc__fixed.html#aaff594f656338fdac5d0fb248117b856',1,'plplotc_fixed.PLESC_IMAGE()']]],
  ['plesc_5fimageops',['PLESC_IMAGEOPS',['../classplplot.html#a7bcdb534a1c7498b4eebb9f8c541e682',1,'plplot::PLESC_IMAGEOPS()'],['../namespaceplplotc.html#aeda20276a961b9f1ce5534c3ce37245e',1,'plplotc.PLESC_IMAGEOPS()'],['../namespaceplplotc__fixed.html#aaacc99aa200334b7bdcf5d31a8f990c9',1,'plplotc_fixed.PLESC_IMAGEOPS()']]],
  ['plesc_5fimport_5fbuffer',['PLESC_IMPORT_BUFFER',['../namespaceplplotc.html#aca0fe6617fc7fa33eef6df4f2a8eb530',1,'plplotc.PLESC_IMPORT_BUFFER()'],['../namespaceplplotc__fixed.html#a8c1dcbcf67cc646b721e3d7477c6573a',1,'plplotc_fixed.PLESC_IMPORT_BUFFER()']]],
  ['plesc_5fmodeget',['PLESC_MODEGET',['../namespaceplplotc.html#a0319c9e155afcbb122d170f627848c1f',1,'plplotc.PLESC_MODEGET()'],['../namespaceplplotc__fixed.html#a5d74403bbf4d71b3e193519734f1a88d',1,'plplotc_fixed.PLESC_MODEGET()']]],
  ['plesc_5fmodeset',['PLESC_MODESET',['../namespaceplplotc.html#a8b9fd0ad5393f5301a06f36b878f4b19',1,'plplotc.PLESC_MODESET()'],['../namespaceplplotc__fixed.html#a63ae4ecea456f408d7bf4712eb3ca099',1,'plplotc_fixed.PLESC_MODESET()']]],
  ['plesc_5fpl2devcol',['PLESC_PL2DEVCOL',['../classplplot.html#a80b4ad54c29d219f548b0c88dade18f7',1,'plplot::PLESC_PL2DEVCOL()'],['../namespaceplplotc.html#ab9198fb986a29a87c3eabd6e36e5ddab',1,'plplotc.PLESC_PL2DEVCOL()'],['../namespaceplplotc__fixed.html#a881dd527b5887e16544fa0800defc3d1',1,'plplotc_fixed.PLESC_PL2DEVCOL()']]],
  ['plesc_5fredraw',['PLESC_REDRAW',['../classplplot.html#a1d45738370d6c2a7cc794a4b1b48dab9',1,'plplot::PLESC_REDRAW()'],['../namespaceplplotc.html#a193d81301fd059cd7fdcf8a883a46d3a',1,'plplotc.PLESC_REDRAW()'],['../namespaceplplotc__fixed.html#a0a3abe3fe73664e15e027e3cb2cf20b6',1,'plplotc_fixed.PLESC_REDRAW()']]],
  ['plesc_5fresize',['PLESC_RESIZE',['../classplplot.html#ad249b2d955c8df2745f15a5db04ccb31',1,'plplot::PLESC_RESIZE()'],['../namespaceplplotc.html#a57016284408a7b4832c0509e9d37b06e',1,'plplotc.PLESC_RESIZE()'],['../namespaceplplotc__fixed.html#af200ebb69add53ef9db27f5eaf1e64cf',1,'plplotc_fixed.PLESC_RESIZE()']]],
  ['plesc_5fset_5fcompression',['PLESC_SET_COMPRESSION',['../classplplot.html#a8bcdaf79b5bbabc4802d69b8174889b8',1,'plplot::PLESC_SET_COMPRESSION()'],['../namespaceplplotc.html#ab4ed01c814c5efbf1cf072f18592475a',1,'plplotc.PLESC_SET_COMPRESSION()'],['../namespaceplplotc__fixed.html#aa6fff5381059bfbee0eaa250a7009bc9',1,'plplotc_fixed.PLESC_SET_COMPRESSION()']]],
  ['plesc_5fset_5flpb',['PLESC_SET_LPB',['../classplplot.html#a61b181837bb486ec54cebf15d7cd4d30',1,'plplot::PLESC_SET_LPB()'],['../namespaceplplotc.html#a7e5cb39b69896c1a5d68304ad0a02943',1,'plplotc.PLESC_SET_LPB()'],['../namespaceplplotc__fixed.html#a96bdf08e92a2e0326cbdf096c15bf0f7',1,'plplotc_fixed.PLESC_SET_LPB()']]],
  ['plesc_5fset_5frgb',['PLESC_SET_RGB',['../classplplot.html#a861f741ff4f852792232de58c3eca85c',1,'plplot::PLESC_SET_RGB()'],['../namespaceplplotc.html#ada7b8a924fb783340dacd8e8a1d33e87',1,'plplotc.PLESC_SET_RGB()'],['../namespaceplplotc__fixed.html#a57812083e0b9908659787b96ca380c79',1,'plplotc_fixed.PLESC_SET_RGB()']]],
  ['plesc_5fsetbgfg',['PLESC_SETBGFG',['../classplplot.html#ab62905aeae38f8946f9141b4bbc39aef',1,'plplot::PLESC_SETBGFG()'],['../namespaceplplotc.html#a86d0b98cb046098478970b53738c0916',1,'plplotc.PLESC_SETBGFG()'],['../namespaceplplotc__fixed.html#a2e48cfb376ac5d351e71392bbb32bec0',1,'plplotc_fixed.PLESC_SETBGFG()']]],
  ['plesc_5fstart_5frasterize',['PLESC_START_RASTERIZE',['../namespaceplplotc.html#af9742dda23e8d3f662e1cb2a3a525148',1,'plplotc.PLESC_START_RASTERIZE()'],['../namespaceplplotc__fixed.html#a1e671a826a005a62823643b56d33a787',1,'plplotc_fixed.PLESC_START_RASTERIZE()']]],
  ['plesc_5fswin',['PLESC_SWIN',['../classplplot.html#a1eee1c2b673f7f1a6fa8f2e6cf02602c',1,'plplot::PLESC_SWIN()'],['../namespaceplplotc.html#a15d0a541754c8cf11fa3b80c9a8c1f6f',1,'plplotc.PLESC_SWIN()'],['../namespaceplplotc__fixed.html#a991930f354ffaae5eeb3bfe9d874cffb',1,'plplotc_fixed.PLESC_SWIN()']]],
  ['plesc_5ftext',['PLESC_TEXT',['../classplplot.html#a212ee183d577400d542ec74a78268b7d',1,'plplot::PLESC_TEXT()'],['../namespaceplplotc.html#ab412042d6d3501a95aeb452b1bc34ffb',1,'plplotc.PLESC_TEXT()'],['../namespaceplplotc__fixed.html#a8ef6fc22a99af5433c740bce27b0486a',1,'plplotc_fixed.PLESC_TEXT()']]],
  ['plesc_5ftext_5fchar',['PLESC_TEXT_CHAR',['../namespaceplplotc.html#a78f3b4c904b70f3c49f9ccb9bf79083b',1,'plplotc.PLESC_TEXT_CHAR()'],['../namespaceplplotc__fixed.html#aaa7aafcd7cb4f52b867eb2b5c322f9f2',1,'plplotc_fixed.PLESC_TEXT_CHAR()']]],
  ['plesc_5fxormod',['PLESC_XORMOD',['../classplplot.html#ab0f6257cc1022a78aaaf66dc551407cf',1,'plplot::PLESC_XORMOD()'],['../namespaceplplotc.html#a32d1e35e35329b80334d9c61dc442f52',1,'plplotc.PLESC_XORMOD()'],['../namespaceplplotc__fixed.html#a3abe0630e74a3e15c77f6070c50fdb2b',1,'plplotc_fixed.PLESC_XORMOD()']]],
  ['plfamadv',['plfamadv',['../classplplot.html#accb5fc9efe774fac0c27ade42896fa3c',1,'plplot']]],
  ['plfgrid',['PLfGrid',['../classplplot.html#a8ad11f18fef6acd1ac3d69c59d681ea2',1,'plplot']]],
  ['plfgrid2',['PLfGrid2',['../classplplot.html#a375e738f3a47becf6b450e4d4095f13a',1,'plplot']]],
  ['plflt',['plflt',['../classplplot.html#af4efe2eb24aa2b34e81343c5e44c8fb2',1,'plplot']]],
  ['plflush',['plflush',['../classplplot.html#a1bd7e4bce7e66986a3bfd8020a00d400',1,'plplot']]],
  ['plfont',['plfont',['../classplplot.html#a143cde9cd53a8fc88bd715d6874078a0',1,'plplot']]],
  ['plfontld',['plfontld',['../classplplot.html#a3ac96186aa875aa8f8b4018d8857ec97',1,'plplot']]],
  ['plgchr',['plgchr',['../classplplot.html#a4740b3152e693a88adf05a2d8fb9cc4c',1,'plplot']]],
  ['plgcol0',['plgcol0',['../classplplot.html#aee668e1f682f284f35de10956712d74e',1,'plplot']]],
  ['plgcol0a',['plgcol0a',['../classplplot.html#aba4d56cf40db646dd70d9ae6cff8bbff',1,'plplot']]],
  ['plgcolbg',['plgcolbg',['../classplplot.html#a4ef5f7d59ba4c288d908e76163d3ccdc',1,'plplot']]],
  ['plgcolbga',['plgcolbga',['../classplplot.html#a5f62e9b006b26ef96ecc6cf7e77531cd',1,'plplot']]],
  ['plgcompression',['plgcompression',['../classplplot.html#a7a81cf632ae9df7cae6c203bbef62630',1,'plplot']]],
  ['plgdidev',['plgdidev',['../classplplot.html#a617604d51d9a80b6686b8308fb3e1c36',1,'plplot']]],
  ['plgdiori',['plgdiori',['../classplplot.html#af961ef5da21a81b18d171376ef94b18c',1,'plplot']]],
  ['plgdiplt',['plgdiplt',['../classplplot.html#abc008579d8fd86bc0c05cc70dc58d9e3',1,'plplot']]],
  ['plgfam',['plgfam',['../classplplot.html#a5fbcfdcebba08a24c6ddb3d6833e0b20',1,'plplot']]],
  ['plgfci',['plgfci',['../classplplot.html#aa8049d9d7507ac6898e1a7aa7c1a7a7a',1,'plplot']]],
  ['plgfont',['plgfont',['../classplplot.html#a49f622e5ecebe8a8a8c533ef7b7147cc',1,'plplot']]],
  ['plglevel',['plglevel',['../classplplot.html#a684a40de7df9b1245ba65418a934acb5',1,'plplot']]],
  ['plgpage',['plgpage',['../classplplot.html#a3ea029481312eba078267195c00ac49f',1,'plplot']]],
  ['plgra',['plgra',['../classplplot.html#af845cb9c21709d1a909f35ac7583b5e6',1,'plplot']]],
  ['plgraphicsin',['PLGraphicsIn',['../classplplot.html#a82e8dbdc52db5d91f5281bfb8c8b0431',1,'plplot']]],
  ['plgraphicsin_5fswigregister',['PLGraphicsIn_swigregister',['../namespaceplplotc.html#a2ed140e1dae13d8870800c18255c50f5',1,'plplotc.PLGraphicsIn_swigregister()'],['../namespaceplplotc__fixed.html#ae4bb745b9823c54f72a9348cd024c0fd',1,'plplotc_fixed.PLGraphicsIn_swigregister()']]],
  ['plgrdient',['plgrdient',['../classplplot.html#a6b1b01c91352e4604dee86e9832dab15',1,'plplot']]],
  ['plgspa',['plgspa',['../classplplot.html#a960542b47254ac706233952c17f631c8',1,'plplot']]],
  ['plgstrm',['plgstrm',['../classplplot.html#a319347f5d960600163067fe46d18f835',1,'plplot']]],
  ['plgvpd',['plgvpd',['../classplplot.html#afeb410421b90295cca78c029641bc1fa',1,'plplot']]],
  ['plgvpw',['plgvpw',['../classplplot.html#ab41fb913fe8ae19776f497b9617d82b1',1,'plplot']]],
  ['plgxax',['plgxax',['../classplplot.html#a085debd0f0bde29e49fec966f523785b',1,'plplot']]],
  ['plgyax',['plgyax',['../classplplot.html#a4f3a12892973912d5a8dee3e1e8a295e',1,'plplot']]],
  ['plgzax',['plgzax',['../classplplot.html#af5c0e84849a4d583319c8ba9ea4f624e',1,'plplot']]],
  ['plhls',['plhls',['../classplplot.html#af689fe17bd5301e7eeadb81df9d63701',1,'plplot']]],
  ['plhlsrgb',['plhlsrgb',['../classplplot.html#af11e32a0abb90a268917a3d52bc5d252',1,'plplot']]],
  ['plinit',['plinit',['../classplplot.html#a2d79ac193881aa0e5afd2b9dca8e86cb',1,'plplot']]],
  ['plint',['PLINT',['../classplplot.html#a31de7bf1fe7bbee8db21098bae902b7b',1,'plplot']]],
  ['pljoin',['pljoin',['../classplplot.html#a3d0a024fee80c4a608278401f2f0844e',1,'plplot']]],
  ['pllightsource',['pllightsource',['../classplplot.html#aea54e9a8e2238a4cbe1de332d285f817',1,'plplot']]],
  ['pllsty',['pllsty',['../classplplot.html#ae50b8882b845df12f536c8e10f33025c',1,'plplot']]],
  ['plmemorymapreservedspace',['plMemoryMapReservedSpace',['../wxwidgets__comms_8h.html#acd377e5f506c131cd44867b0ae34401e',1,'wxwidgets_comms.h']]],
  ['plmeridians',['plmeridians',['../classplplot.html#a836b948926218fb942b7b68b1d8fe985',1,'plplot']]],
  ['plminmax2dgrid',['plMinMax2dGrid',['../namespaceplplotc.html#a02d5cc5e9830406ed04d933dc91b5f34',1,'plplotc.plMinMax2dGrid()'],['../namespaceplplotc__fixed.html#a8a00c9364773e771df2e192e7d7b9064',1,'plplotc_fixed.plMinMax2dGrid()']]],
  ['plmkstrm',['plmkstrm',['../classplplot.html#ad4729e332c9db6847a940c4a5352c154',1,'plplot']]],
  ['ploption_5finfo',['ploption_info',['../plargs_8c.html#a28b780f5686638ec8da7d7b7a0e1353a',1,'plargs.c']]],
  ['ploption_5finfo_5fdefault',['ploption_info_default',['../plargs_8c.html#a328df00d833e1a37283d2d8b0977b1c9',1,'plargs.c']]],
  ['ploption_5ftable',['ploption_table',['../plargs_8c.html#a9b3b70f82dd73a63cbf927911c746982',1,'plargs.c']]],
  ['ploptiontable',['PLOptionTable',['../classplplot.html#adad93e76e186a31ff7d640cb6fcb3929',1,'plplot']]],
  ['ploptusage',['plOptUsage',['../namespaceplplotc.html#a91a52af2917540a0f9fa00c3c55c2dd2',1,'plplotc.plOptUsage()'],['../namespaceplplotc__fixed.html#a47eadfdf7b878e8a40e4560bc91ddeda',1,'plplotc_fixed.plOptUsage()']]],
  ['plot_5f2005_5fheader',['plot_2005_header',['../plmetafile_8c.html#a460859263bfdca8b9c6ddbaab138ffba',1,'plmetafile.c']]],
  ['plot_5fheader',['plot_header',['../struct__plm__version.html#aad0fc113068616e044495cd0dd057dbe',1,'_plm_version']]],
  ['plp_5fgreek_5fmnemonic',['plP_greek_mnemonic',['../plcore_8c.html#a4e3b3e20867b5eb19bc1ea4014e0c7ec',1,'plP_greek_mnemonic():&#160;plcore.c'],['../plplotP_8h.html#a4e3b3e20867b5eb19bc1ea4014e0c7ec',1,'plP_greek_mnemonic():&#160;plcore.c']]],
  ['plp_5fgvpd',['plP_gvpd',['../classplplot.html#ab3e0f6270d0e196edd9e955c6bd3be45',1,'plplot']]],
  ['plp_5fgvpw',['plP_gvpw',['../classplplot.html#a786fc5cb91f37bec488f2ff914e12032',1,'plplot']]],
  ['plp_5ftype',['plp_type',['../struct__plm__format.html#a226b200074a29df992f8feaa2d5b30fe',1,'_plm_format']]],
  ['plpage',['plpage',['../classplplot.html#a8d1e19a3d2b1302dce0fc6d6e1031ccf',1,'plplot']]],
  ['plpath',['plpath',['../classplplot.html#a9a74b0d5ef9492e9552f32f0edd23f07',1,'plplot']]],
  ['plplot_5fccmap',['plplot_ccmap',['../plxwd_8h.html#a75b2632f0a1230d5173060415f8df303',1,'plxwd.h']]],
  ['plplot_5fnotes',['plplot_notes',['../plargs_8c.html#a2e4785f19ff0f8d5cce0494e8e607376',1,'plargs.c']]],
  ['plplot_5ftkwin_5fccmap',['plplot_tkwin_ccmap',['../pltkwd_8h.html#a75aa0f644a3eff27e35ecc0e82f2247e',1,'pltkwd.h']]],
  ['plplotlibdir',['plplotLibDir',['../plctrl_8c.html#a4ce541bc2941502478f734a5a4d0a060',1,'plplotLibDir():&#160;plctrl.c'],['../tclAPI_8c.html#aecc09632d4e39fd61019c56b064b2475',1,'plplotLibDir():&#160;plctrl.c']]],
  ['plplotqt_5fsmoke',['plplotqt_Smoke',['../plplotqt__smoke_8h.html#ac9e79be6efe920104bd37238781f3313',1,'plplotqt_smoke.h']]],
  ['plplotterptr',['plPlotterPtr',['../structPLStream.html#a9d81841ac0ad6a24645f9f04e115bf31',1,'PLStream']]],
  ['plpointer',['PLPointer',['../classplplot.html#ab4c487625f5fe57d3596a974a4ac01e8',1,'plplot']]],
  ['plpr_5fcmd',['plpr_cmd',['../structPlFrame.html#aceaba949a67a76f868e08ae274b44949',1,'PlFrame::plpr_cmd()'],['../structPlPlotter.html#a416b098639e9b47f568673b9c76905f3',1,'PlPlotter::plpr_cmd()']]],
  ['plprec',['plprec',['../classplplot.html#a53419da11726b76f962f76474579d482',1,'plplot']]],
  ['plpsty',['plpsty',['../classplplot.html#a85a8e7a9fe415d6d467fed88ac7425fa',1,'plplot']]],
  ['plr',['plr',['../structPlFrame.html#a713cd12a3c1a8120371415df1ed51020',1,'PlFrame::plr()'],['../structPlPlotter.html#a4c1dcc5b699ad2637b0ce73fc5ddc7fb',1,'PlPlotter::plr()']]],
  ['plrandd',['plrandd',['../classplplot.html#a25aab7f205ac187d6d68ee3a930f98e6',1,'plplot']]],
  ['plreplot',['plreplot',['../classplplot.html#a06dbd3cd8ad2c0390a254e1ee9a1cf72',1,'plplot']]],
  ['plresetopts',['plResetOpts',['../namespaceplplotc.html#af38c58a760449cb53d7b41b76d19b27b',1,'plplotc.plResetOpts()'],['../namespaceplplotc__fixed.html#aa94adf96d12e4f4660c55504634f1ecc',1,'plplotc_fixed.plResetOpts()']]],
  ['plrgb',['plrgb',['../classplplot.html#af04d711c7bb1bc2517cce2d11f1cf814',1,'plplot']]],
  ['plrgb1',['plrgb1',['../classplplot.html#a405247d752782554a6cdff5990f37abf',1,'plplot']]],
  ['plrgbhls',['plrgbhls',['../classplplot.html#ab4238ee20a5f2e96ceeb37735c5dfc0b',1,'plplot']]],
  ['pls',['pls',['../structPlFrame.html#a982084e3d22ae071b5520bd191988f87',1,'PlFrame::pls()'],['../structPlPlotter.html#a3ac8671b5e060a49d2b35baace8d2a3a',1,'PlPlotter::pls()'],['../classQtPLDriver.html#a014da339a8826aec1036904e0ad41214',1,'QtPLDriver::pls()'],['../plcore_8h.html#a890f7a97464cf72ce84e76713210e252',1,'pls():&#160;plcore.h']]],
  ['pls0',['pls0',['../plcore_8h.html#a6e47a18278140fcb0aee110effdac390',1,'plcore.h']]],
  ['plschr',['plschr',['../classplplot.html#ad6cd0529533f2cc181419ca7074542d1',1,'plplot']]],
  ['plscmap0n',['plscmap0n',['../classplplot.html#ab9a5f82e8597b07980b6b82567ad1142',1,'plplot']]],
  ['plscmap1_5frange',['plscmap1_range',['../classplplot.html#ab9c238eaf06c3f112b133a27c18bbc0a',1,'plplot']]],
  ['plscmap1n',['plscmap1n',['../classplplot.html#acb861d5300a5c6ac3933bd7729fc05f5',1,'plplot']]],
  ['plscol0',['plscol0',['../classplplot.html#ab9680ca15d97e394b220a3f2f18f4b57',1,'plplot']]],
  ['plscol0a',['plscol0a',['../classplplot.html#ad47805ae72e397df030b927da8910188',1,'plplot']]],
  ['plscolbg',['plscolbg',['../classplplot.html#a72f5ce4b770385225aad8c0b76efa39c',1,'plplot']]],
  ['plscolbga',['plscolbga',['../classplplot.html#af7f482f30c637a9ba44df1252a314ebd',1,'plplot']]],
  ['plscolor',['plscolor',['../classplplot.html#ae3f5358ddd16cd7da58a9fa66dc47bed',1,'plplot']]],
  ['plscompression',['plscompression',['../classplplot.html#afe9412a621fba4de36072b41ebe5d846',1,'plplot']]],
  ['plsdidev',['plsdidev',['../classplplot.html#a6516d20a9b431a865bd2c9441b7d584b',1,'plplot']]],
  ['plsdimap',['plsdimap',['../classplplot.html#a76329f12d4bcadbdbc283e0b7d6bc940',1,'plplot']]],
  ['plsdiori',['plsdiori',['../classplplot.html#a637dd2d2ad4325426efa3b61df84d544',1,'plplot']]],
  ['plsdiplt',['plsdiplt',['../classplplot.html#ab3c67aadedee13ab0df9377dce043efc',1,'plplot']]],
  ['plsdiplz',['plsdiplz',['../classplplot.html#a7675975e9ecb0a6a00126ec284bb9ace',1,'plplot']]],
  ['plseed',['plseed',['../classplplot.html#a09494b7075775c8444a1763089e0416c',1,'plplot']]],
  ['plserver',['plserver',['../structPLStream.html#a1b41113a10d760085aa3f61ee4313b59',1,'PLStream']]],
  ['plsesc',['plsesc',['../classplplot.html#ac637bc0b6cd60b2675192b3028679649',1,'plplot']]],
  ['plsetusage',['plSetUsage',['../namespaceplplotc.html#a21768491ad01b676ba51c3fe07729727',1,'plplotc.plSetUsage()'],['../namespaceplplotc__fixed.html#a2c7b426efc4d46bb5ef368d36add1814',1,'plplotc_fixed.plSetUsage()']]],
  ['plsfam',['plsfam',['../classplplot.html#adc832b0c8c0fa6548fa98bee741f0bf1',1,'plplot']]],
  ['plsfci',['plsfci',['../classplplot.html#a2a902e5d8a9f551d9da2e6af704da9ed',1,'plplot']]],
  ['plsfont',['plsfont',['../classplplot.html#ae5cc0e6c15cd5964b0233a691e27c8fd',1,'plplot']]],
  ['plslabelfunc',['plslabelfunc',['../classplplot.html#a478fbbc530aa2127e1a530a569968ecc',1,'plplot']]],
  ['plsmaj',['plsmaj',['../classplplot.html#aa1086fbb8f3a73083b205f14783c9c11',1,'plplot']]],
  ['plsmem',['plsmem',['../classplplot.html#a707227bacf7694b6ab3161ea9ce6e1d2',1,'plplot']]],
  ['plsmin',['plsmin',['../classplplot.html#a1603215a3b917adc7b4ab0b790867344',1,'plplot']]],
  ['plsori',['plsori',['../classplplot.html#afd09c57f50f8004fb766f24388b9d0b7',1,'plplot']]],
  ['plspage',['plspage',['../classplplot.html#a066171bf8dd4a36cd74e6eac59bf609d',1,'plplot']]],
  ['plspause',['plspause',['../classplplot.html#a5031282d76c363257ee14bec3c132038',1,'plplot']]],
  ['plsstrm',['plsstrm',['../classplplot.html#ae257e5409828a91e9ef7d4117b738fe0',1,'plplot']]],
  ['plssub',['plssub',['../classplplot.html#a06994b5bad5a5fcbbd870073a8b17fdf',1,'plplot']]],
  ['plssym',['plssym',['../classplplot.html#a547da7c62d0e52733af100eebf25b7ba',1,'plplot']]],
  ['plstar',['plstar',['../classplplot.html#ae8357a44ea95b90fb8c8d8043e381806',1,'plplot']]],
  ['plstransform',['plstransform',['../classplplot.html#a7630fb082e626b8fdcc23fdb260b66f5',1,'plplot']]],
  ['plstripa',['plstripa',['../classplplot.html#aa92f13bd259d65d50bf775a72eff0a91',1,'plplot']]],
  ['plstripd',['plstripd',['../classplplot.html#aac3e6742466acd0bebc51af04dd08e13',1,'plplot']]],
  ['plsvpa',['plsvpa',['../classplplot.html#ac81b9e82d78b1afa029336f30042db38',1,'plplot']]],
  ['plswin_5fdevice',['PLSWIN_DEVICE',['../classplplot.html#a23e11e97f2e5237fc18c6d0026ddfbf9',1,'plplot::PLSWIN_DEVICE()'],['../namespaceplplotc.html#a9546c5be25c4dee3cedf4d3531e0a271',1,'plplotc.PLSWIN_DEVICE()'],['../namespaceplplotc__fixed.html#a4e9756decffdd2d34bf703ab13152caa',1,'plplotc_fixed.PLSWIN_DEVICE()']]],
  ['plswin_5fworld',['PLSWIN_WORLD',['../classplplot.html#aee9ccfe5fe54a3f7831598f159eadbcd',1,'plplot::PLSWIN_WORLD()'],['../namespaceplplotc.html#a068d68799b04f081e6647a74cc239049',1,'plplotc.PLSWIN_WORLD()'],['../namespaceplplotc__fixed.html#a7d9472d562f256d1316b521a77522c0f',1,'plplotc_fixed.PLSWIN_WORLD()']]],
  ['plsxax',['plsxax',['../classplplot.html#adaf430d0e3383ed209149a1a8059c3c2',1,'plplot']]],
  ['plsxwin',['plsxwin',['../namespaceplplotc.html#a334c3242c3767b8820e67016c523434f',1,'plplotc.plsxwin()'],['../namespaceplplotc__fixed.html#ad305585f8749773157db6b57d0e6de81',1,'plplotc_fixed.plsxwin()']]],
  ['plsyax',['plsyax',['../classplplot.html#a3440233c89f0188596a7f773b0f4ebf3',1,'plplot']]],
  ['plszax',['plszax',['../classplplot.html#a489016ad9024f3613f14a5474f915efb',1,'plplot']]],
  ['pltcl_5fnotes',['pltcl_notes',['../tclMain_8c.html#a02e75d18d06f7cb1b632b8ae7e1c2dd7',1,'tclMain.c']]],
  ['pltext',['pltext',['../classplplot.html#a250d95fcf548bc4dd658d3ddc02c8f37',1,'plplot']]],
  ['pltext_5fbackchar',['PLTEXT_BACKCHAR',['../namespaceplplotc.html#a3d7a89e051b17190397dfceee0498fa6',1,'plplotc.PLTEXT_BACKCHAR()'],['../namespaceplplotc__fixed.html#a38fec2caf210726063ebe0de7ca1f1fe',1,'plplotc_fixed.PLTEXT_BACKCHAR()']]],
  ['pltext_5ffontchange',['PLTEXT_FONTCHANGE',['../namespaceplplotc.html#a898327e28e20a75486b73eb0bd38fafc',1,'plplotc.PLTEXT_FONTCHANGE()'],['../namespaceplplotc__fixed.html#a0195b9b6ee0e6f0e578f4c52ea776667',1,'plplotc_fixed.PLTEXT_FONTCHANGE()']]],
  ['pltext_5foverline',['PLTEXT_OVERLINE',['../namespaceplplotc.html#a1f8604c47436bdaa3e323c633c669874',1,'plplotc.PLTEXT_OVERLINE()'],['../namespaceplplotc__fixed.html#a56e5dd252db6559c3a69dda9d5a28907',1,'plplotc_fixed.PLTEXT_OVERLINE()']]],
  ['pltext_5fsubscript',['PLTEXT_SUBSCRIPT',['../namespaceplplotc.html#ae2fa706d7ce77d27b12df4d1dd6ddf39',1,'plplotc.PLTEXT_SUBSCRIPT()'],['../namespaceplplotc__fixed.html#a5940a6e4770592956b491711815be102',1,'plplotc_fixed.PLTEXT_SUBSCRIPT()']]],
  ['pltext_5fsuperscript',['PLTEXT_SUPERSCRIPT',['../namespaceplplotc.html#a873a0fb7dee097cd6a1a9586327863c7',1,'plplotc.PLTEXT_SUPERSCRIPT()'],['../namespaceplplotc__fixed.html#a6455050c5899d32c2b73c54773481c19',1,'plplotc_fixed.PLTEXT_SUPERSCRIPT()']]],
  ['pltext_5funderline',['PLTEXT_UNDERLINE',['../namespaceplplotc.html#a6a448b26bc2a80db2cb5736710d27cf4',1,'plplotc.PLTEXT_UNDERLINE()'],['../namespaceplplotc__fixed.html#a256939bd4d4ac694b7cac3bd46b49272',1,'plplotc_fixed.PLTEXT_UNDERLINE()']]],
  ['pltr0',['pltr0',['../namespaceplplotc.html#a1a3d30415da615635d94e4b2c3d96204',1,'plplotc.pltr0()'],['../namespaceplplotc__fixed.html#a21a5a4b79976f85993d3d2ed7059c546',1,'plplotc_fixed.pltr0()']]],
  ['pltr1',['pltr1',['../namespaceplplotc.html#a5ab0ac0ec378324110aa4e00e0f5aab4',1,'plplotc.pltr1()'],['../namespaceplplotc__fixed.html#a48541260090563bddbb9c4f8842620d0',1,'plplotc_fixed.pltr1()']]],
  ['pltr2',['pltr2',['../namespaceplplotc.html#ade02f9b8fdd455998a19d329c375efb5',1,'plplotc.pltr2()'],['../namespaceplplotc__fixed.html#aa729218d82b539d47475146724751a88',1,'plplotc_fixed.pltr2()']]],
  ['pltr_5ftype',['pltr_type',['../plplotcPYTHON__wrap_8c.html#ac1ba1957081dd47cfc51c81b349fb65a',1,'plplotcPYTHON_wrap.c']]],
  ['pltr_5fxg',['pltr_xg',['../plplotcPYTHON__wrap_8c.html#abc329ab5d5455e741b49a7cfca82b74c',1,'plplotcPYTHON_wrap.c']]],
  ['pltr_5fyg',['pltr_yg',['../plplotcPYTHON__wrap_8c.html#acab766c33a03fec035a91e4d28e150a2',1,'plplotcPYTHON_wrap.c']]],
  ['plunicode',['PLUNICODE',['../classplplot.html#ae6821277959dc78b2623efa4c6293b12',1,'plplot']]],
  ['plvasp',['plvasp',['../classplplot.html#a6d01a94c0ac3f7e1fa7e72eabad1179b',1,'plplot']]],
  ['plvpas',['plvpas',['../classplplot.html#acda6f8cf1dd36564c294fcc170b557d3',1,'plplot']]],
  ['plvpor',['plvpor',['../classplplot.html#a337563b49b342e18ea2c372c38ae9962',1,'plplot']]],
  ['plvsta',['plvsta',['../classplplot.html#ae0d90e76073ffa70669e95f60d4f8b4b',1,'plplot']]],
  ['plw3d',['plw3d',['../classplplot.html#a7b7e981d7224c5c72cf27741314a1a48',1,'plplot']]],
  ['plwidth',['plwidth',['../classplplot.html#a8d35de2ce79d7bfec3f744b36617a1a7',1,'plplot']]],
  ['plwin',['plwin',['../structPLStream.html#a77ff47b0b2433a55000be9791d845aef',1,'PLStream']]],
  ['plwind',['plwind',['../classplplot.html#afa1fbb244390844aaf38c6ef7e63ff2a',1,'plplot']]],
  ['plwindow',['PLWindow',['../classplplot.html#adceee7930422cfa970f42901b6b64346',1,'plplot::PLWindow()'],['../structPLStream.html#a6ef609e12b8b5c9b9e151b8e8c441a06',1,'PLStream::plwindow()']]],
  ['plxormod',['plxormod',['../classplplot.html#ae78f5f7d2f17258acdd9d17dc2daafe8',1,'plplot']]],
  ['point_5ftriangles',['point_triangles',['../structdelaunay.html#a4736654ae35ea8703729bc2ff8e5ce8f',1,'delaunay']]],
  ['points',['points',['../structtriangle.html#ad5bce2373e18f7171ee1a9c8d1067883',1,'triangle::points()'],['../structsquare.html#ac7c665ada2c891807a31095e97b51bcb',1,'square::points()'],['../structcsa.html#a97ea910069b4e92797dffdfc0becb45d',1,'csa::points()'],['../structdelaunay.html#a0d1839b31e05a2341ab0a63619eec538',1,'delaunay::points()']]],
  ['portrait',['portrait',['../structPLStream.html#ac8562587fa9d5077836abfafc88cd8ca',1,'PLStream']]],
  ['precis',['precis',['../structPLStream.html#aa0bbd34b62e61bcc154cd8844abcf7b7',1,'PLStream']]],
  ['prev',['prev',['../structswig__cast__info.html#a0f5d1fc81b494c3e032a153609fd3268',1,'swig_cast_info']]],
  ['prevheight',['prevHeight',['../structPlFrame.html#ab526a3322941789668dd1bdb9a2d1eec',1,'PlFrame::prevHeight()'],['../structPlPlotter.html#a43facd3bd2374d5486eca286f3dd8ecf',1,'PlPlotter::prevHeight()']]],
  ['previoushandle',['previousHandle',['../struct____dlhandle.html#a2f305d15c0aaca3690a4d00ac177254a',1,'__dlhandle']]],
  ['prevwidth',['prevWidth',['../structPlFrame.html#acf6172aba13e57f624c83847652e6a21',1,'PlFrame::prevWidth()'],['../structPlPlotter.html#ac94f5b6bdd1bbf773e64652a26d5a829',1,'PlPlotter::prevWidth()']]],
  ['primary',['primary',['../structtriangle.html#ab64aa930abf392d43df10fca642ca9f2',1,'triangle::primary()'],['../structsquare.html#a4b34e290cec4a2a80e296523deebb7a6',1,'square::primary()']]],
  ['private_5fdouble',['private_double',['../classplplot__types.html#aa370c0f9b45cc07d2eee6f4e215906f2',1,'plplot_types']]],
  ['private_5fplbool',['private_plbool',['../classplplot__types.html#ab525eefa1fbe06d8b20029fb27dda452',1,'plplot_types']]],
  ['private_5fplint',['private_plint',['../classplplot__types.html#acfd5a979e1645e3db5a076dc7dfbc2c8',1,'plplot_types']]],
  ['private_5fplunicode',['private_plunicode',['../classplplot__types.html#a114f8a9249534e58b49288a2b980f1fb',1,'plplot_types']]],
  ['private_5fsingle',['private_single',['../classplplot__types.html#ae1d3100e1eada67b180246e174bca16c',1,'plplot_types']]],
  ['proc',['proc',['../structCommand.html#a5de85b5abc27f7779a805d2f7d1a110f',1,'Command::proc()'],['../structCmdInfo.html#aa857b93f722a58a2db3b534055f18fb0',1,'CmdInfo::proc()']]],
  ['program',['program',['../structPLStream.html#a896aa6409612b3db3cce8dda0a52e572',1,'PLStream::program()'],['../plargs_8c.html#a17410ae7332a3410b3edb8b0070f7d73',1,'program():&#160;plargs.c']]],
  ['psdoc',['psdoc',['../structPLStream.html#a1eabdffbd0bd29ae235b3e73a1bd2181',1,'PLStream']]],
  ['pt',['pt',['../structcsa.html#ab50c1428c4ee43cc1de760e4f2092476',1,'csa::pt()'],['../structTextSizeInfo.html#a28c66f8dec6a7b6e8e26abf5c4e3ed87',1,'TextSizeInfo::pt()']]],
  ['ptcnt',['ptcnt',['../structPSDev.html#a50801b5e97eba8ab9ac0d3430c2c79d6',1,'PSDev']]],
  ['ptr',['ptr',['../structswig__lua__userdata.html#a2d3be052ee0b81986ab31ef5dc08fd25',1,'swig_lua_userdata::ptr()'],['../structoctave__swig__type_1_1cpp__ptr.html#a6deed8dec899518d7f25c417faceef1e',1,'octave_swig_type::cpp_ptr::ptr()'],['../classoctave__swig__ref.html#aa3d5c16467cfdb3cab00b1ff086dc4b0',1,'octave_swig_ref::ptr()'],['../structSwigPyObject.html#a41b1d569a8ba4fa9b1d87579c144891b',1,'SwigPyObject::ptr()']]],
  ['pts',['pts',['../structPlFrame.html#a9830a818bdfed5fa040583a0ddb611c5',1,'PlFrame::pts()'],['../structPlPlotter.html#abd18feea1193e753b2a4eaeaba99e94e',1,'PlPlotter::pts()']]],
  ['ptype',['ptype',['../structswig__lua__const__info.html#a0557056988d98840029075f204d2bf59',1,'swig_lua_const_info::ptype()'],['../structswig__const__info.html#aedd46d173c5b5ed4ee60ad5660233557',1,'swig_const_info::ptype()']]],
  ['put',['put',['../structtclMatrix.html#a12ddbdf9fa8106de061fc66ca0be9d27',1,'tclMatrix']]],
  ['pvalue',['pvalue',['../structswig__lua__const__info.html#a54637f2603b1179d4996c06e82e3f23a',1,'swig_lua_const_info::pvalue()'],['../structswig__const__info.html#abbc43512c364bff11fac5961c1155090',1,'swig_const_info::pvalue()']]],
  ['px',['px',['../structplplot__graphics_1_1plgraphicsin.html#ae4a00e0a17bb6592041308831dac1b3d',1,'plplot_graphics::plgraphicsin::px()'],['../structplplot_1_1__N2.html#a4d588287a6595c7ba20977b449c2aa4e',1,'plplot::_N2::pX()'],['../structPLGraphicsIn.html#a65a7c2ad35465fdda2da1cdad78c6fed',1,'PLGraphicsIn::pX()']]],
  ['pxlx',['pxlx',['../structPLmDev.html#ae41ae47a21545c83ab0c3ace2fb46cfe',1,'PLmDev::pxlx()'],['../structPLDev.html#a357154f1b97fcc69c434ad9220dda746',1,'PLDev::pxlx()'],['../structPSDev.html#af0b2d28b35838694ff24f90af6d95213',1,'PSDev::pxlx()']]],
  ['pxly',['pxly',['../structPLmDev.html#afcaf79a40e6fce0c4234017d6411b098',1,'PLmDev::pxly()'],['../structPLDev.html#a3c3bffd26090366eb11df6537508e0fa',1,'PLDev::pxly()'],['../structPSDev.html#ac12a32c014bc6200acd8ddd50fa4f1f1',1,'PSDev::pxly()']]],
  ['py',['pY',['../structplplot_1_1__N2.html#a0815facf07c4811909f0bf3b0c87316a',1,'plplot::_N2::pY()'],['../structPLGraphicsIn.html#a21b1933fd85acc870381e8a8a176b259',1,'PLGraphicsIn::pY()'],['../structplplot__graphics_1_1plgraphicsin.html#ac68342e0093fe3100f4aea9e89578580',1,'plplot_graphics::plgraphicsin::py()']]],
  ['python_5fct',['python_ct',['../plplotcPYTHON__wrap_8c.html#accd45e261658e868dbba9789704cb8d5',1,'plplotcPYTHON_wrap.c']]],
  ['python_5ff2eval',['python_f2eval',['../plplotcPYTHON__wrap_8c.html#a487895e00ae9be090c71512415fc35d6',1,'plplotcPYTHON_wrap.c']]],
  ['python_5flabel',['python_label',['../plplotcPYTHON__wrap_8c.html#a728cbc7612574a50db094ae556e4b368',1,'plplotcPYTHON_wrap.c']]],
  ['python_5fmapform',['python_mapform',['../plplotcPYTHON__wrap_8c.html#aa64bb28869b331ad013625fbad5cdf57',1,'plplotcPYTHON_wrap.c']]],
  ['python_5fpltr',['python_pltr',['../plplotcPYTHON__wrap_8c.html#a9606f0b730c8f4c62e20c00e2dfde1c6',1,'plplotcPYTHON_wrap.c']]],
  ['pytype',['pytype',['../structSwigPyClientData.html#a1f172e51bb27f670dacdf8247843b4c2',1,'SwigPyClientData']]]
];
